function [ret,x0,str,ts,xts]=boussol1(t,x,u,flag);
%BOUSSOL1	is the M-file description of the SIMULINK system named BOUSSOL1.
%	The block-diagram can be displayed by typing: BOUSSOL1.
%
%	SYS=BOUSSOL1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BOUSSOL1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BOUSSOL1 with a FLAG of zero:
%	[SIZES]=BOUSSOL1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,62,1267,959])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    'instant_injection')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '0.4')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'simulation de base reg_derb.m, adapte au cas puls']])
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'simulation de base reg_derb.m, adapte au cas puls']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[623,60,628,65])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[610,505,615,510])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[200,510,205,515])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[385,485,390,490])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[440,240,445,245])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[4,50,1267,947])
open_system([sys,'/','UnNamed1'])

add_block('built-in/Note',[sys,'/','UnNamed1/Q'])
set_param([sys,'/','UnNamed1/Q'],...
		'position',[295,440,300,445])

add_block('built-in/Note',[sys,'/','UnNamed1/pqr'])
set_param([sys,'/','UnNamed1/pqr'],...
		'position',[325,375,330,380])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','[3 4]',...
		'position',[225,375,275,495])

add_block('built-in/Note',[sys,'/',['UnNamed1/tau',13,'']])
set_param([sys,'/',['UnNamed1/tau',13,'']],...
		'position',[85,240,90,245])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[105,335,110,340])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[75,300,95,320])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace4'])
set_param([sys,'/','UnNamed1/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','quater',...
		'buffer','2500',...
		'position',[325,460,390,490])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression de',13,'toutes les',13,'perturbations']])
set_param([sys,'/',['UnNamed1/Suppression de',13,'toutes les',13,'perturbations']],...
		'position',[515,325,520,330])

add_block('built-in/Note',[sys,'/','UnNamed1/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION'])
set_param([sys,'/','UnNamed1/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[630,40,635,45])

add_block('built-in/Note',[sys,'/','UnNamed1/Cette simulation permet de vrifier :'])
set_param([sys,'/','UnNamed1/Cette simulation permet de vrifier :'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[365,530,370,535])

add_block('built-in/Note',[sys,'/',['UnNamed1/Le mouvement de Poinsot  ( matrice d''inertie diagonale de rvolution +  aucun couple )']])
set_param([sys,'/',['UnNamed1/Le mouvement de Poinsot  ( matrice d''inertie diagonale de rvolution +  aucun couple )']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[650,560,655,565])

add_block('built-in/Note',[sys,'/',['UnNamed1/La conservation de l''nergie',13,'']])
set_param([sys,'/',['UnNamed1/La conservation de l''nergie',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[395,585,400,590])

add_block('built-in/Note',[sys,'/',['UnNamed1/La rgulation en ''BPOINT'' seule avec l''oscillation finale au double de la pulsation orbitale']])
set_param([sys,'/',['UnNamed1/La rgulation en ''BPOINT'' seule avec l''oscillation finale au double de la pulsation orbitale']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[655,615,660,620])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],'Location',[4,195,1271,801])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[285,282,415,338])


%     Subsystem  'UnNamed1/Subsystem1'.

new_system([sys,'/','UnNamed1/Subsystem1'])
set_param([sys,'/','UnNamed1/Subsystem1'],'Location',[61,122,1222,668])
open_system([sys,'/','UnNamed1/Subsystem1'])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace3'],...
		'hide name',0,...
		'mat-name','mz_deriv',...
		'buffer','points_trace',...
		'position',[800,160,880,180])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace2'],...
		'hide name',0,...
		'mat-name','my_deriv',...
		'buffer','points_trace',...
		'position',[800,125,880,145])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace1'],...
		'hide name',0,...
		'mat-name','mx_deriv',...
		'buffer','points_trace',...
		'position',[800,90,880,110])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem1/Outport'])
set_param([sys,'/','UnNamed1/Subsystem1/Outport'],...
		'position',[1135,320,1155,340])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux1'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[880,202,930,453])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Couple magntique',13,'']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[965,313,1025,347])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem1/To Workspace'])
set_param([sys,'/','UnNamed1/Subsystem1/To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_deriv',...
		'buffer','points_trace',...
		'position',[1075,235,1155,255])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux2'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[780,194,810,336])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem1/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem1/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[670,195,710,335])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[400,102,405,107])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE DE B ET UN GAIN MATRICIEL'])
set_param([sys,'/','UnNamed1/Subsystem1/REGULATION PAR LA DERIVEE DE B ET UN GAIN MATRICIEL'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[555,10,560,15])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Champ rel'])
set_param([sys,'/','UnNamed1/Subsystem1/Champ rel'],...
		'position',[625,365,630,370])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Sortie du couple gnr',13,'par la commande drive de B']])
set_param([sys,'/',['UnNamed1/Subsystem1/Sortie du couple gnr',13,'par la commande drive de B']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[1025,460,1030,465])


%     Subsystem  ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES'].

new_system([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],'Location',[442,254,1087,515])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/in_1']],...
		'hide name',0,...
		'position',[25,100,45,120])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_3']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_3']],...
		'hide name',0,...
		'Port','3',...
		'position',[360,130,380,150])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_2']],...
		'hide name',0,...
		'position',[360,70,380,90])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_1']],...
		'hide name',0,...
		'Port','2',...
		'position',[360,100,380,120])


%     Subsystem  ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem'].

new_system([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],'Location',[4,301,1154,596])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_3']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_3']],...
		'Port','3',...
		'position',[760,185,780,205])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_2']],...
		'Port','2',...
		'position',[760,145,780,165])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_1']],...
		'position',[760,105,780,125])


%     Subsystem  ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3'].

new_system([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],'Location',[154,322,1099,787])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_1']],...
		'position',[115,190,135,210])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ rel satellite']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ rel satellite']],...
		'position',[690,55,695,60])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ  liss']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ  liss']],...
		'position',[775,115,780,120])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive pulse non lisse']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive pulse non lisse']],...
		'position',[790,425,795,430])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_3']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_3']],...
		'position',[800,390,820,410])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_1']],...
		'Port','3',...
		'position',[780,45,800,65])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_2']],...
		'Port','2',...
		'position',[790,145,810,165])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Sum']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Sum']],...
		'hide name',0,...
		'position',[640,134,665,321])


%     Subsystem  ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE'].

new_system([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],'Location',[4,50,853,441])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_2']],...
		'Port','2',...
		'position',[95,250,115,270])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])


%     Subsystem  ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'].

new_system([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],'Location',[125,1114771,765,1115016])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[175,70,180,75])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1']],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1']],...
		'position',[525,105,545,125])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1']],...
		'position',[245,115,265,135])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[345,145;345,85;470,85])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[500,115;520,115])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[270,125;290,125])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'].

set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],...
		'hide name',0,...
		'position',[155,236,295,284])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']],...
		'hide name',0,...
		'mat-name','der_seconde',...
		'buffer','20000',...
		'position',[705,568,825,602])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau']],...
		'position',[785,211,790,216])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)']],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT']],...
		'position',[395,310,400,315])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/out_1']],...
		'position',[715,215,735,235])

add_block('built-in/To File',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']],...
		'File name','derbchap.mat',...
		'Matrix name','derb_chapeau',...
		'position',[635,134,730,166])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'position',[515,208,575,242])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_1']],...
		'position',[105,135,125,155])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta']],...
		'position',[390,290,395,295])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']],...
		'hide name',0,...
		'mat-name','derb_chapeau',...
		'buffer','20000',...
		'position',[630,268,750,302])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[325,189,360,211])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,168,400,292])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT']],...
		'position',[335,235,340,240])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1']],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime']],...
		'position',[550,175,555,180])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz ']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz ']],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3,...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Size',12,...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Size',12,...
		'position',[420,45,425,50])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[120,260;150,260])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[580,225;710,225])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[595,225;595,150;630,150])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[595,225;595,285;625,285])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[490,225;510,225])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[405,230;450,230])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[365,200;370,200])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[130,145;430,145;430,215;450,215])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[300,260;370,260])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE'].

set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],...
		'position',[310,260,445,340])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Calcul t-nT']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Calcul t-nT']],...
		'hide name',0,...
		'position',[410,385,415,390])

add_block('built-in/Product',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Product']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Product']],...
		'position',[535,227,560,323])


%     Subsystem  ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE'].

new_system([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],'Location',[198,215,1097,749])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_1']],...
		'Port','2',...
		'position',[615,220,635,240])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_3']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_3']],...
		'position',[615,100,635,120])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/in_1']],...
		'position',[65,210,85,230])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz ']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz ']],...
		'position',[115,180,120,185])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT']],...
		'hide name',0,...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau']],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT']],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Mux1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Mux1']],...
		'inputs','[3 1]',...
		'position',[445,211,475,244])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storcham(u)',...
		'Output Width','3',...
		'position',[505,213,565,247])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_2']],...
		'Port','3',...
		'position',[615,420,635,440])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[610,272,660,288])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,258,400,382])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[305,279,340,301])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT']],...
		'position',[585,385,590,390])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])


%     Subsystem  ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'].

new_system([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],'Location',[163,376,803,621])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1']],...
		'position',[555,105,575,125])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'ForeGround',3,...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'position',[315,0,320,5])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[135,100,140,105])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'MATLAB Fcn','fix(u/T)*T',...
		'Output Width','1')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']],...
		'hide name',0,...
		'Value','instant_injection',...
		'position',[165,154,270,176])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1']],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1']],...
		'position',[245,115,265,135])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[345,145;345,85;470,85])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[500,115;550,115])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[270,125;290,125])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'].

set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],...
		'hide name',0,...
		'position',[115,326,255,374])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Clock2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Clock2']],...
		'hide name',0,...
		'position',[45,330,85,370])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']],...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[140,412,190,428])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t-nT']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t-nT']],...
		'position',[930,355,935,360])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3,...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'position',[360,5,365,10])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,220;440,220])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[390,220;390,110;610,110])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,350;90,420;135,420])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,350;110,350])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[345,290;370,290])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[570,230;610,230])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[590,230;590,280;605,280])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[405,320;430,320;440,235])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[480,230;500,230])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[260,350;285,350;285,430;610,430])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[285,350;370,350])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE'].

set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],...
		'position',[300,165,435,235])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive B']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive B']],...
		'position',[495,270,500,275])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/derb_chapeau']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/derb_chapeau']],...
		'position',[535,335,540,340])

add_block('built-in/Derivative',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive de',13,'B relle']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive de',13,'B relle']],...
		'position',[230,262,285,298])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/t -tinj - nT']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/t -tinj - nT']],...
		'position',[500,225,505,230])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/B(n)']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/B(n)']],...
		'position',[535,175,540,180])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[130,120,135,125])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Temps']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Temps']],...
		'position',[130,285,135,290])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_2']],...
		'Port','2',...
		'position',[110,310,130,330])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux']],...
		'outputs','3',...
		'position',[505,94,545,126])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux1']],...
		'outputs','3',...
		'position',[680,349,720,381])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']],...
		'hide name',0,...
		'mat-name','b_reel_roulis',...
		'buffer','points_trace',...
		'position',[580,84,660,116])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']],...
		'hide name',0,...
		'mat-name','derb_pulse_roulis',...
		'buffer','points_trace',...
		'position',[755,339,870,371])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']],...
		'hide name',0,...
		'mat-name','champ_pulse',...
		'buffer','points_trace',...
		'position',[745,213,865,247])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']],...
		'hide name',0,...
		'mat-name','b_pulse_roulis',...
		'buffer','points_trace',...
		'position',[825,269,905,301])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux2']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux2']],...
		'outputs','3',...
		'position',[750,279,790,311])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux3']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux3']],...
		'outputs','3',...
		'position',[375,419,415,451])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']],...
		'hide name',0,...
		'mat-name','derb_reel_roulis',...
		'buffer','points_trace',...
		'position',[460,409,540,441])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[670,230;740,230])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[685,230;685,155;785,155])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[450,300;530,300])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[475,300;475,400;795,400])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,175;465,175;465,55;775,55])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[135,320;305,320])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[290,280;305,280])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[565,275;635,275])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,225;455,225;455,250;530,250])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,200;580,200;580,180;635,180])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[140,200;295,200])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[275,200;190,200;190,280;225,280])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[465,110;500,110])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[615,400;615,365;675,365])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[550,100;575,100])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[725,355;750,355])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[795,285;820,285])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[710,230;710,295;745,295])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[420,425;455,425])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[290,280;290,435;370,435])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'Mask Display','Champ rel\n&\nchamp mesur')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3'].

set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'hide name',0,...
		'position',[595,97,730,213])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Drive pulse crneau(mesure )']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Drive pulse crneau(mesure )']],...
		'position',[930,100,935,105])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ puls liss linairement ( mesure )']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ puls liss linairement ( mesure )']],...
		'position',[950,140,955,145])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ rel']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ rel']],...
		'position',[870,185,875,190])


%     Subsystem  ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],'Location',[382,182,1228,651])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'position',[240,88,440,162])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/in_1']],...
		'position',[160,115,180,135])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Clock']])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Clock']],...
		'position',[150,168,190,202])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[195,185;590,185])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,115;755,115])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,155;755,155])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,195;755,195])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[185,125;235,125])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[445,125;590,125])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES + CHAMP REEL')


%     Finished composite block ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem'].

set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],...
		'hide name',0,...
		'position',[85,64,285,156])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],[290,80;355,80])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],[290,110;355,110])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],[290,140;355,140])
add_line([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],[50,110;80,110])
set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES')


%     Finished composite block ['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES'].

set_param([sys,'/',['UnNamed1/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],...
		'position',[70,193,210,267])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem1/in_1'])
set_param([sys,'/','UnNamed1/Subsystem1/in_1'],...
		'position',[15,220,35,240])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/B'])
set_param([sys,'/','UnNamed1/Subsystem1/B'],...
		'position',[235,275,240,280])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['UnNamed1/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'position',[130,345,135,350])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux3'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux3'],...
		'hide name',0,...
		'inputs','[3 7]',...
		'position',[255,284,290,366])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Moments',13,'magntique',13,'de',13,'consigne',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem1/Moments',13,'magntique',13,'de',13,'consigne',13,'']],...
		'MATLAB Fcn','mom_magn(u)',...
		'Output Width','3',...
		'position',[315,308,375,342])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/Puls',13,'linaire']])
set_param([sys,'/',['UnNamed1/Subsystem1/Puls',13,'linaire']],...
		'position',[360,210,365,215])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Pulse crneau'])
set_param([sys,'/','UnNamed1/Subsystem1/Pulse crneau'],...
		'position',[270,175,275,180])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/B''']])
set_param([sys,'/',['UnNamed1/Subsystem1/B''']],...
		'position',[425,180,430,185])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem1/Moments ',13,'magntiques',13,' gnrer']])
set_param([sys,'/',['UnNamed1/Subsystem1/Moments ',13,'magntiques',13,' gnrer']],...
		'MATLAB Fcn','laurens(u)',...
		'Output Width','3',...
		'position',[580,248,640,282])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/B '])
set_param([sys,'/','UnNamed1/Subsystem1/B '],...
		'position',[430,225,435,230])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem1/Bc'])
set_param([sys,'/','UnNamed1/Subsystem1/Bc'],...
		'position',[430,270,435,275])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem1/Mux'])
set_param([sys,'/','UnNamed1/Subsystem1/Mux'],...
		'hide name',0,...
		'inputs','[3 3 3 3]',...
		'position',[510,181,545,364])

add_block('built-in/Derivative',[sys,'/','UnNamed1/Subsystem1/Derivative'])
set_param([sys,'/','UnNamed1/Subsystem1/Derivative'],...
		'position',[435,329,480,351])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem1/B''c']])
set_param([sys,'/',['UnNamed1/Subsystem1/B''c']],...
		'position',[495,310,500,315])
add_line([sys,'/','UnNamed1/Subsystem1'],[715,220;775,220])
add_line([sys,'/','UnNamed1/Subsystem1'],[730,220;730,100;795,100])
add_line([sys,'/','UnNamed1/Subsystem1'],[715,265;775,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[750,265;750,135;795,135])
add_line([sys,'/','UnNamed1/Subsystem1'],[715,310;775,310])
add_line([sys,'/','UnNamed1/Subsystem1'],[765,310;765,170;795,170])
add_line([sys,'/','UnNamed1/Subsystem1'],[815,265;875,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[645,265;665,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[40,230;65,230])
add_line([sys,'/','UnNamed1/Subsystem1'],[935,330;960,330])
add_line([sys,'/','UnNamed1/Subsystem1'],[1030,330;1130,330])
add_line([sys,'/','UnNamed1/Subsystem1'],[1030,330;1030,245;1070,245])
add_line([sys,'/','UnNamed1/Subsystem1'],[215,205;505,205])
add_line([sys,'/','UnNamed1/Subsystem1'],[215,230;405,230;405,250;505,250])
add_line([sys,'/','UnNamed1/Subsystem1'],[215,255;390,255;390,390;875,390])
add_line([sys,'/','UnNamed1/Subsystem1'],[40,230;40,345;250,345])
add_line([sys,'/','UnNamed1/Subsystem1'],[225,230;225,305;250,305])
add_line([sys,'/','UnNamed1/Subsystem1'],[295,325;310,325])
add_line([sys,'/','UnNamed1/Subsystem1'],[550,275;575,265])
add_line([sys,'/','UnNamed1/Subsystem1'],[380,325;410,325;410,295;505,295])
add_line([sys,'/','UnNamed1/Subsystem1'],[485,340;505,340])
add_line([sys,'/','UnNamed1/Subsystem1'],[410,325;410,340;430,340])
set_param([sys,'/','UnNamed1/Subsystem1'],...
		'Mask Display','REGULATION BOUSSOLE\n\nTECHNIQUE LAURENS\n\nPULSEE')


%     Finished composite block 'UnNamed1/Subsystem1'.

set_param([sys,'/','UnNamed1/Subsystem1'],...
		'hide name',0,...
		'position',[220,176,450,254])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain3'])
set_param([sys,'/','UnNamed1/Gain3'],...
		'hide name',0,...
		'Gain','K_poinsot',...
		'position',[885,248,925,282])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']])
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[745,242,845,288])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[1125,325,1145,345])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain1'])
set_param([sys,'/','UnNamed1/Gain1'],...
		'hide name',0,...
		'position',[1070,322,1095,348])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum1'])
set_param([sys,'/','UnNamed1/Sum1'],...
		'position',[970,194,1010,476])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m1'])
set_param([sys,'/','UnNamed1/magneto.m1'],...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[610,379,735,431])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression de',13,'tous les couples']])
set_param([sys,'/',['UnNamed1/Suppression de',13,'tous les couples']],...
		'position',[900,205,905,210])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum2'])
set_param([sys,'/','UnNamed1/Sum2'],...
		'hide name',0,...
		'position',[680,169,725,356])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain2'])
set_param([sys,'/','UnNamed1/Gain2'],...
		'Gain','-1',...
		'position',[470,200,515,230])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain'])
set_param([sys,'/','UnNamed1/Gain'],...
		'hide name',0,...
		'position',[460,293,500,327])


%     Subsystem  'UnNamed1/Subsystem5'.

new_system([sys,'/','UnNamed1/Subsystem5'])
set_param([sys,'/','UnNamed1/Subsystem5'],'Location',[298,510,1135,815])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem5/out_1'])
set_param([sys,'/','UnNamed1/Subsystem5/out_1'],...
		'position',[635,140,655,160])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem5/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem5/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_avant',...
		'buffer','points_trace',...
		'position',[205,38,295,52])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem5/Demux'])
set_param([sys,'/','UnNamed1/Subsystem5/Demux'],...
		'outputs','3',...
		'position',[140,39,180,71])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem5/in_1'])
set_param([sys,'/','UnNamed1/Subsystem5/in_1'],...
		'position',[65,100,85,120])


%     Subsystem  'UnNamed1/Subsystem5/Subsystem5'.

new_system([sys,'/','UnNamed1/Subsystem5/Subsystem5'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5'],'Location',[580,281,938,501])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem5/Subsystem5/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','valeur_creneau',...
		'buffer','points_trace',...
		'position',[245,178,340,192])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem5/Subsystem5/Clock'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem5/Subsystem5/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem5/Subsystem5/in_1'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem5/Subsystem5/Product'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem5/Subsystem5/out_1'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem5/Subsystem5/CRENEAU'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem5/Subsystem5/To Workspace4'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_creneau',...
		'buffer','points_trace',...
		'position',[125,193,220,207])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[185,130;225,130])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[205,130;205,185;240,185])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[85,130;115,130])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[255,110;290,110])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[140,85;225,85])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[85,130;85,195;120,200])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'UnNamed1/Subsystem5/Subsystem5'.

set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[190,84,315,136])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem5/Gain2'])
set_param([sys,'/','UnNamed1/Subsystem5/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem5/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem5/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem5/Gain1'])
set_param([sys,'/','UnNamed1/Subsystem5/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[230,170,365,210])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem5/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_apres',...
		'buffer','points_trace',...
		'position',[580,23,675,37])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem5/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem5/Demux1'],...
		'outputs','3',...
		'position',[505,24,545,56])
add_line([sys,'/','UnNamed1/Subsystem5'],[90,110;125,110;125,190;225,190])
add_line([sys,'/','UnNamed1/Subsystem5'],[105,110;105,55;135,55])
add_line([sys,'/','UnNamed1/Subsystem5'],[185,45;200,45])
add_line([sys,'/','UnNamed1/Subsystem5'],[550,150;630,150])
add_line([sys,'/','UnNamed1/Subsystem5'],[320,110;335,110])
add_line([sys,'/','UnNamed1/Subsystem5'],[370,190;520,190])
add_line([sys,'/','UnNamed1/Subsystem5'],[480,110;520,110])
add_line([sys,'/','UnNamed1/Subsystem5'],[90,110;185,110])
add_line([sys,'/','UnNamed1/Subsystem5'],[550,30;575,30])
add_line([sys,'/','UnNamed1/Subsystem5'],[480,110;480,40;500,40])
set_param([sys,'/','UnNamed1/Subsystem5'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'UnNamed1/Subsystem5'.

set_param([sys,'/','UnNamed1/Subsystem5'],...
		'hide name',0,...
		'position',[545,191,630,239])
add_line([sys,'/','UnNamed1'],[420,310;455,310])
add_line([sys,'/','UnNamed1'],[280,405;605,405])
add_line([sys,'/','UnNamed1'],[280,465;310,465;320,475])
add_line([sys,'/','UnNamed1'],[1015,335;1065,335])
add_line([sys,'/','UnNamed1'],[1100,335;1120,335])
add_line([sys,'/','UnNamed1'],[100,310;280,310])
add_line([sys,'/','UnNamed1'],[190,310;190,435;220,435])
add_line([sys,'/','UnNamed1'],[190,310;190,215;215,215])
add_line([sys,'/','UnNamed1'],[455,215;465,215])
add_line([sys,'/','UnNamed1'],[505,310;675,310])
add_line([sys,'/','UnNamed1'],[730,265;740,265])
add_line([sys,'/','UnNamed1'],[850,265;880,265])
add_line([sys,'/','UnNamed1'],[930,265;965,265])
add_line([sys,'/','UnNamed1'],[740,405;965,405])
add_line([sys,'/','UnNamed1'],[520,215;540,215])
add_line([sys,'/','UnNamed1'],[635,215;675,215])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[145,233,370,317])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[430,420,435,425])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[140,368,355,472])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[640,324,740,376])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[535,255,540,260])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[530,395,535,400])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,50,1260,942])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[905,670,910,675])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[915,624,1000,656])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/To File',[sys,'/','Subsystem/To File3'])
set_param([sys,'/','Subsystem/To File3'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','temps',...
		'position',[1115,547,1205,593])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])


%     Subsystem  ['Subsystem/Vitesses angulaires',13,'rd//s'].

new_system([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/x']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],[90,65;125,65])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Entries','5000\/-0.2\/0.2\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Subsystem/Vitesses angulaires',13,'rd//s'].

set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'orientation',2,...
		'BackGround',2,...
		'position',[365,192,475,228])


%     Subsystem  'Subsystem/Angles en degrs'.

new_system([sys,'/','Subsystem/Angles en degrs'])
set_param([sys,'/','Subsystem/Angles en degrs'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Subsystem/Angles en degrs/x'])
set_param([sys,'/','Subsystem/Angles en degrs/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Subsystem/Angles en degrs'],[90,65;125,65])
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Entries','5000\/-200\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Subsystem/Angles en degrs'.

set_param([sys,'/','Subsystem/Angles en degrs'],...
		'orientation',2,...
		'BackGround',2,...
		'position',[705,522,815,558])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[290,415,310,435])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;845,380])
add_line([sys,'/','Subsystem'],[315,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;960,535])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;910,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem'],[930,535;930,570;1110,570])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[550,210;480,210])
add_line([sys,'/','Subsystem'],[840,465;840,540;820,540])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[860,201,1055,274])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[805,255,810,260])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[805,190,810,195])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[559,482,1161,775])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'position',[55,63,115,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[350,63,390,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[370,27,420,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'position',[185,63,265,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[345,140,350,145])
add_line([sys,'/','Subsystem2'],[40,80;50,80])
add_line([sys,'/','Subsystem2'],[120,80;180,80])
add_line([sys,'/','Subsystem2'],[270,80;345,80])
add_line([sys,'/','Subsystem2'],[300,80;300,35;365,35])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[640,193,725,247])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[520,204,580,491])

add_block('built-in/Note',[sys,'/',['DETUMBLING AVEC QUATERNION D''ATTITUDE ',13,'ETUDE DU TANGAGE ROULIS ET LACET',13,'',13,'',13,'']])
set_param([sys,'/',['DETUMBLING AVEC QUATERNION D''ATTITUDE ',13,'ETUDE DU TANGAGE ROULIS ET LACET',13,'',13,'',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[635,0,640,5])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[115,615,315,681])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r);grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[115,685,320,746])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir la vitesse angulaire\nde tangage seul (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,q);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[115,750,320,811])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, my, mz',...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[330,615,555,676])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=bleu\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[330,685,560,771])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,615,770,671])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,685,770,751])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Voir la commande \navant le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_avant);grid;figure(gcf)'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[780,615,980,681])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Champs magntiques\nrel roulis\npuls linaire roulis',...
		'Mask Dialogue','eval(''plot(temps,b_reel_roulis,temps,b_pulse_roulis);grid;figure(gcf)'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[995,610,1195,676])


%     Subsystem  'Extras19'.

new_system([sys,'/','Extras19'])
set_param([sys,'/','Extras19'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras19'],...
		'Mask Display','Champs magn drivs\nrel roulis\npuls constant roulis',...
		'Mask Dialogue','eval(''plot(temps,derb_reel_roulis,temps,derb_pulse_roulis);grid;figure(gcf)'')')


%     Finished composite block 'Extras19'.

set_param([sys,'/','Extras19'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[995,685,1195,751])


%     Subsystem  'Extras18'.

new_system([sys,'/','Extras18'])
set_param([sys,'/','Extras18'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras18'],...
		'Mask Display','Voir la commande \napres le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_apres);grid;figure(gcf)'')')


%     Finished composite block 'Extras18'.

set_param([sys,'/','Extras18'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[780,690,980,756])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[680,565,685,570])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem1/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem1/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem1/d) Lancer la simulation'])
set_param([sys,'/','Subsystem1/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem1/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem1/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem1/b) '])
set_param([sys,'/','Subsystem1/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem1/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem1/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','LIRE LES EXPLICATIONS')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[130,825,480,861])


%     Subsystem  'Subsystem4'.

new_system([sys,'/','Subsystem4'])
set_param([sys,'/','Subsystem4'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem4/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem4/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem4/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem4/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem4/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem4/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem4/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem4/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem4/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem4/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem4/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem4/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem4/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem4/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem4/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem4/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem4/d) Lancer la simulation'])
set_param([sys,'/','Subsystem4/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem4/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem4/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem4/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem4/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem4/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem4/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem4/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem4/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem4/b) '])
set_param([sys,'/','Subsystem4/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem4/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem4/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem4/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem4/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem4/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem4/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])
set_param([sys,'/','Subsystem4'],...
		'Mask Display','LANCER L''ACQUISITION GROSSIERE',...
		'Mask Dialogue','eval(''regacqGP'');')


%     Finished composite block 'Subsystem4'.

set_param([sys,'/','Subsystem4'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[865,530,1215,566])


%     Subsystem  'Extras20'.

new_system([sys,'/','Extras20'])
set_param([sys,'/','Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras20'],...
		'Mask Display','Voir la commande \napres le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_avant-com_apres);grid;figure(gcf)'')')


%     Finished composite block 'Extras20'.

set_param([sys,'/','Extras20'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[785,765,985,831])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance derivdat.m, puls par dfaut',13,'']])
set_param([sys,'/',['L''initialisation',13,' lance derivdat.m, puls par dfaut',13,'']],...
		'BackGround',6,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[985,475,990,480])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''derivdat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[870,400,1070,466])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[184,206,1171,591])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'position',[15,105,35,125])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux1'])
set_param([sys,'/','Subsystem3/Mux1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[370,100,395,160])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux'])
set_param([sys,'/','Subsystem3/Demux'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'outputs','[3 3]',...
		'position',[265,96,305,129])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/MATLAB Fcn'])
set_param([sys,'/','Subsystem3/MATLAB Fcn'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'position',[175,98,235,132])

add_block('built-in/Clock',[sys,'/','Subsystem3/Clock'])
set_param([sys,'/','Subsystem3/Clock'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[305,158,340,192])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace3'])
set_param([sys,'/','Subsystem3/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_init_GP',...
		'buffer','1',...
		'position',[655,213,755,237])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace2'])
set_param([sys,'/','Subsystem3/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','initpqrQ_GP',...
		'buffer','1',...
		'position',[660,316,775,344])

add_block('built-in/To File',[sys,'/','Subsystem3/To File'])
set_param([sys,'/','Subsystem3/To File'],...
		'hide name',0,...
		'File name','init_GP.mat',...
		'Matrix name','init_acqGP',...
		'position',[640,247,780,283])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux'])
set_param([sys,'/','Subsystem3/Mux'],...
		'inputs','[1 7]',...
		'position',[525,226,590,299])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace'])
set_param([sys,'/','Subsystem3/To Workspace'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','init_tmc_fin',...
		'buffer','1',...
		'position',[450,118,550,142])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace1'])
set_param([sys,'/','Subsystem3/To Workspace1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_init_tmcfin',...
		'buffer','1',...
		'position',[450,163,555,187])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux2'])
set_param([sys,'/','Subsystem3/Mux2'],...
		'inputs','[6 1]',...
		'position',[610,66,650,179])

add_block('built-in/To File',[sys,'/','Subsystem3/To File1'])
set_param([sys,'/','Subsystem3/To File1'],...
		'hide name',0,...
		'File name','init_fin.mat',...
		'Matrix name','init_mod_fin',...
		'position',[675,107,815,143])

add_block('built-in/Note',[sys,'/','Subsystem3/Sorties pour mode fin'])
set_param([sys,'/','Subsystem3/Sorties pour mode fin'],...
		'position',[890,110,895,115])

add_block('built-in/Note',[sys,'/',['Subsystem3/Sorties pour Acquisition ',13,'grossire']])
set_param([sys,'/',['Subsystem3/Sorties pour Acquisition ',13,'grossire']],...
		'position',[870,240,875,245])

add_block('built-in/Note',[sys,'/','Subsystem3/Transmission des valeurs finales'])
set_param([sys,'/','Subsystem3/Transmission des valeurs finales'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[450,15,455,20])
add_line([sys,'/','Subsystem3'],[345,175;445,175])
add_line([sys,'/','Subsystem3'],[400,130;445,130])
add_line([sys,'/','Subsystem3'],[310,120;325,120;325,115;365,115])
add_line([sys,'/','Subsystem3'],[310,105;340,105;340,145;365,145])
add_line([sys,'/','Subsystem3'],[240,115;260,115])
add_line([sys,'/','Subsystem3'],[40,115;170,115])
add_line([sys,'/','Subsystem3'],[365,175;365,245;520,245])
add_line([sys,'/','Subsystem3'],[595,265;635,265])
add_line([sys,'/','Subsystem3'],[110,115;110,330;655,330])
add_line([sys,'/','Subsystem3'],[300,330;300,280;520,280])
add_line([sys,'/','Subsystem3'],[365,225;650,225])
add_line([sys,'/','Subsystem3'],[420,175;420,150;605,150])
add_line([sys,'/','Subsystem3'],[425,130;425,95;605,95])
add_line([sys,'/','Subsystem3'],[655,125;670,125])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','SORTIES DES CONDITIONS\nFINALES DEVANT SERVIR\nDE CONDITIONS INITIALES\nA LA FUTURE SIMULATION')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[855,307,1100,393])
add_line(sys,[745,350;765,350;765,505;55,505;55,420;135,420])
add_line(sys,[585,350;635,350])
add_line(sys,[375,275;515,275])
add_line(sys,[360,420;515,420])
add_line(sys,[765,350;765,220;855,220])
add_line(sys,[615,350;615,255;855,255])
add_line(sys,[55,420;55,275;140,275])
add_line(sys,[765,220;730,220])
add_line(sys,[765,350;850,350])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
