function [ret,x0,str,ts,xts]=regderb5(t,x,u,flag);
%REGDERB5	is the M-file description of the SIMULINK system named REGDERB5.
%	The block-diagram can be displayed by typing: REGDERB5.
%
%	SYS=REGDERB5(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes REGDERB5 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling REGDERB5 with a FLAG of zero:
%	[SIZES]=REGDERB5([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[6,70,1259,974])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    'temps_init_GP')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '5')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['SIMULATION regderb5.m    Intgration initialise par initpqrQ_GP.mat',13,'']])
set_param([sys,'/',['SIMULATION regderb5.m    Intgration initialise par initpqrQ_GP.mat',13,'']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[630,85,635,90])

add_block('built-in/Note',[sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'']])
set_param([sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[620,125,625,130])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1010,640,1185,706])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1015,725,1190,791])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[530,410,535,415])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[535,270,540,275])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','initpqrQ_GP',...
		'position',[640,339,740,391])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[515,219,575,506])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,450])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[140,383,355,487])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[430,435,435,440])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[440,255,445,260])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[385,500,390,505])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[200,525,205,530])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[610,520,615,525])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[430,585,435,590])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,50,1012,686])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[330,710,560,796])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[85,635,285,701])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,650,770,706])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance acq_dat5.m']])
set_param([sys,'/',['L''initialisation',13,' lance acq_dat5.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1130,370,1135,375])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[800,330,805,335])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[426,267,1120,560])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'position',[55,63,115,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[350,63,390,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[370,27,420,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[185,63,265,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[345,140,350,145])
add_line([sys,'/','Subsystem2'],[40,80;50,80])
add_line([sys,'/','Subsystem2'],[120,80;180,80])
add_line([sys,'/','Subsystem2'],[270,80;345,80])
add_line([sys,'/','Subsystem2'],[300,80;300,35;365,35])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[635,268,720,322])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[765,265,770,270])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem1/d) Lancer la simulation'])
set_param([sys,'/','Subsystem1/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem1/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem1/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem1/b) '])
set_param([sys,'/','Subsystem1/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem1/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem1/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation principale c''est ACQ_DAT3.M']])
set_param([sys,'/',['Subsystem1/Pour la simulation principale c''est ACQ_DAT3.M']],...
		'Font Size',14,...
		'position',[405,125,410,130])

add_block('built-in/Note',[sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,90,500,95])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','LIRE LES EXPLICATIONS')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[820,580,1170,616])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance acq_dat3.m']])
set_param([sys,'/',['L''initialisation',13,' lance acq_dat3.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1130,460,1135,465])


%     Subsystem  'Extras2'.

new_system([sys,'/','Extras2'])
set_param([sys,'/','Extras2'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras2'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''acq_dat3'')')


%     Finished composite block 'Extras2'.

set_param([sys,'/','Extras2'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[830,460,1045,531])

add_block('built-in/To Workspace',[sys,'/','To Workspace12'])
set_param([sys,'/','To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','init1by1',...
		'buffer','1',...
		'Mask Display','TRANSMISSION DES CONDITIONS\nFINALES A LA SIMULATION|\nSUIVANTE')
set_param([sys,'/','To Workspace12'],...
		'position',[820,198,1070,262])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,76,1267,1003])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Fcn',[sys,'/','Subsystem/Fcn'])
set_param([sys,'/','Subsystem/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[720,325,760,345])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusq2',...
		'buffer','points_trace',...
		'position',[805,325,875,345])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/To File',[sys,'/','Subsystem/To File3'])
set_param([sys,'/','Subsystem/To File3'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','temps',...
		'position',[1115,547,1205,593])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace10'])
set_param([sys,'/','Subsystem/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[800,272,900,298])

add_block('built-in/Note',[sys,'/','Subsystem/Vrifications Poinsot'])
set_param([sys,'/','Subsystem/Vrifications Poinsot'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[965,295,970,300])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Note',[sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']])
set_param([sys,'/',['Subsystem/Reste  sortir les angles',13,'',13,'']],...
		'position',[235,230,240,235])

add_block('built-in/Note',[sys,'/','Subsystem/Reste  mettre un stop'])
set_param([sys,'/','Subsystem/Reste  mettre un stop'],...
		'position',[235,205,240,210])

add_block('built-in/Note',[sys,'/',['Subsystem/Mettre une saturation',13,'',13,'']])
set_param([sys,'/',['Subsystem/Mettre une saturation',13,'',13,'']],...
		'position',[230,255,235,260])

add_block('built-in/Note',[sys,'/','Subsystem/Mettre des filtres'])
set_param([sys,'/','Subsystem/Mettre des filtres'],...
		'position',[225,310,230,315])

add_block('built-in/Note',[sys,'/','Subsystem/Mettre des retards'])
set_param([sys,'/','Subsystem/Mettre des retards'],...
		'position',[230,280,235,285])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])

add_block('built-in/Scope',[sys,'/','Subsystem/Scope'])
set_param([sys,'/','Subsystem/Scope'],...
		'Vgain','0.200000',...
		'Hgain','5000.000000',...
		'Vmax','0.400000',...
		'Hmax','10000.000000',...
		'Window',[314,357,1072,756],...
		'position',[865,130,895,160])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[935,624,1020,656])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[915,575,920,580])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn5'])
set_param([sys,'/','Subsystem/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[965,731,1045,769])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace18'])
set_param([sys,'/','Subsystem/To Workspace18'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie_relative',...
		'buffer','points_trace',...
		'position',[1080,737,1215,763])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;845,380])
add_line([sys,'/','Subsystem'],[425,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;960,535])
add_line([sys,'/','Subsystem'],[660,380;660,335;715,335])
add_line([sys,'/','Subsystem'],[765,335;800,335])
add_line([sys,'/','Subsystem'],[660,335;660,285;795,285])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;930,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem'],[930,535;930,570;1110,570])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[685,210;685,145;860,145])
add_line([sys,'/','Subsystem'],[915,640;915,750;960,750])
add_line([sys,'/','Subsystem'],[1050,750;1075,750])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[845,281,1040,354])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\nmoments magntiques \nmx, my, mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[325,640,575,701])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''acq_dat5'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[825,375,1040,446])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[55,68,90,102])

add_block('built-in/Note',[sys,'/',['',13,'PHASE DU DETUMBLING INITIAL',13,'A L''ACQUISITION FINE']])
set_param([sys,'/',['',13,'PHASE DU DETUMBLING INITIAL',13,'A L''ACQUISITION FINE']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[633,0,638,5])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r);grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[80,715,285,776])


%     Subsystem  'Extras15'.

new_system([sys,'/','Extras15'])
set_param([sys,'/','Extras15'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras15'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nphi teta psi (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras15'.

set_param([sys,'/','Extras15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[85,790,290,851])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCphi, Cteta,Cpsi',...
		'Mask Dialogue','eval(''plot(temps,cpl_phi,temps,cpl_teta,temps,cpl_psi);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,720,770,786])


%     Subsystem  'Extras14'.

new_system([sys,'/','Extras14'])
set_param([sys,'/','Extras14'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras14'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCx, Cy,Cz',...
		'Mask Dialogue','eval(''plot(temps,Cx,temps,Cy,temps,Cz);grid;figure(gcf)'')')


%     Finished composite block 'Extras14'.

set_param([sys,'/','Extras14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,790,770,856])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Voir la courbe\n\nenergie relative (J)',...
		'Mask Dialogue','eval(''plot(temps,energie_relative);grid;figure(gcf)'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[345,800,545,856])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[0,46,1263,943])

add_block('built-in/Note',[sys,'/','UnNamed1/pqr'])
set_param([sys,'/','UnNamed1/pqr'],...
		'position',[245,130,250,135])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m1'])
set_param([sys,'/','UnNamed1/magneto.m1'],...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[360,131,495,189])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[80,105,85,110])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','[3 4]',...
		'position',[160,133,205,242])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[55,180,75,200])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain1'])
set_param([sys,'/','UnNamed1/Gain1'],...
		'position',[1080,247,1105,273])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[1145,250,1165,270])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum1'])
set_param([sys,'/','UnNamed1/Sum1'],...
		'inputs','+++',...
		'position',[1030,113,1050,407])

add_block('built-in/Note',[sys,'/','UnNamed1/Q'])
set_param([sys,'/','UnNamed1/Q'],...
		'position',[220,205,225,210])

add_block('built-in/Note',[sys,'/',['UnNamed1/Couple roue',13,'uniaxial']])
set_param([sys,'/',['UnNamed1/Couple roue',13,'uniaxial']],...
		'position',[705,635,710,640])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum'])
set_param([sys,'/','UnNamed1/Sum'],...
		'position',[760,315,785,495])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']])
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[845,382,945,428])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain4'])
set_param([sys,'/','UnNamed1/Gain4'],...
		'hide name',0,...
		'position',[970,392,995,418])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression possible',13,'de tous les couples']])
set_param([sys,'/',['UnNamed1/Suppression possible',13,'de tous les couples']],...
		'position',[920,330,925,335])

add_block('built-in/Note',[sys,'/',['UnNamed1/Second membre',13,'des quations du TMC',13,'concernant le vecteur rotation',13,'seul (p q r )']])
set_param([sys,'/',['UnNamed1/Second membre',13,'des quations du TMC',13,'concernant le vecteur rotation',13,'seul (p q r )']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1095,440,1100,445])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux1'])
set_param([sys,'/','UnNamed1/Demux1'],...
		'outputs','3',...
		'position',[810,515,855,625])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace1'])
set_param([sys,'/','UnNamed1/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Cx',...
		'buffer','points_trace',...
		'position',[900,527,950,543])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace2'])
set_param([sys,'/','UnNamed1/To Workspace2'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Cy',...
		'buffer','points_trace',...
		'position',[900,562,950,578])

add_block('built-in/Note',[sys,'/',['UnNamed1/Sorties des commande en',13,'axes satellite x y z']])
set_param([sys,'/',['UnNamed1/Sorties des commande en',13,'axes satellite x y z']],...
		'position',[1035,545,1040,550])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace3'])
set_param([sys,'/','UnNamed1/To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Cz',...
		'buffer','points_trace',...
		'position',[895,597,945,613])

add_block('built-in/Note',[sys,'/','UnNamed1/F(X,t) POUR LA DERIVEE DE LA ROTATION ABSOLUE'])
set_param([sys,'/','UnNamed1/F(X,t) POUR LA DERIVEE DE LA ROTATION ABSOLUE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',24,...
		'position',[655,15,660,20])


%     Subsystem  'UnNamed1/Subsystem4'.

new_system([sys,'/','UnNamed1/Subsystem4'])
set_param([sys,'/','UnNamed1/Subsystem4'],'Location',[5,51,955,501])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem4/Angles  rd'])
set_param([sys,'/','UnNamed1/Subsystem4/Angles  rd'],...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[125,153,185,187])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem4/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem4/Demux1'],...
		'outputs','[3 4]',...
		'position',[55,88,100,197])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem4/in_1'])
set_param([sys,'/','UnNamed1/Subsystem4/in_1'],...
		'position',[15,135,35,155])

add_block('built-in/Derivative',[sys,'/','UnNamed1/Subsystem4/Derivative'])
set_param([sys,'/','UnNamed1/Subsystem4/Derivative'],...
		'position',[235,91,295,139])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Mux'])
set_param([sys,'/','UnNamed1/Subsystem4/Mux'],...
		'inputs','[3 3]',...
		'position',[325,85,360,200])


%     Subsystem  'UnNamed1/Subsystem4/Subsystem3'.

new_system([sys,'/','UnNamed1/Subsystem4/Subsystem3'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3'],'Location',[4,103,1267,977])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/in_1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/in_1'],...
		'position',[15,310,35,330])


%     Subsystem  'UnNamed1/Subsystem4/Subsystem3/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],'Location',[94,120,1204,806])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/mz'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/mz'],...
		'position',[550,645,555,650])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/1//By'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/1//By'],...
		'position',[500,640,505,645])


%     Subsystem  ['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],'Location',[195,367,1041,836])


%     Subsystem  ['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

new_system([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],'Location',[27,258,1102,698])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bx']],...
		'position',[804,170,809,175])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Bz']],...
		'position',[804,290,809,295])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BZ']],...
		'position',[715,325,720,330])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[910,170,915,175])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/out_1']],...
		'position',[965,230,985,250])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Display','Axe x',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/',...
		'position',[415,93,470,127])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Demux']],...
		'outputs','3',...
		'position',[520,44,580,76])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,100,565,135])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/By']],...
		'position',[784,215,789,220])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[820,220,865,260])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BY']],...
		'position',[730,205,735,210])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/BX']],...
		'position',[740,75,745,80])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum']],...
		'hide name',0,...
		'position',[755,95,775,130])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Display','Axe y',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/',...
		'position',[415,223,470,257])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[535,230,565,265])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'hide name',0,...
		'position',[755,220,770,260])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'hide name',0,...
		'position',[755,339,790,381])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'position',[615,349,675,391])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Display','Axe z',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/',...
		'position',[415,338,470,372])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[540,344,570,391])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Angles']],...
		'position',[439,145,444,150])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'position',[600,104,665,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','u(1:3)''*u(4:6)',...
		'Output Width','1')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'position',[590,234,665,266])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[305,25,310,30])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Temps']],...
		'position',[85,65,90,70])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'position',[180,85,355,135])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Clock']],...
		'position',[115,100,135,120])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']],...
		'position',[273,165,278,170])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1/in_2']],...
		'position',[120,160,140,180])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[795,360;795,255;815,255])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[780,115;795,115;795,225;815,225])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,50;720,50;720,105;750,105])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,60;705,60;705,230;750,230])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[585,70;690,70;690,350;750,350])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[360,110;410,110])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,60;515,60])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[775,240;815,240])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,110;380,355;410,355])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[380,240;410,240])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[145,170;510,170;510,125;530,125])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,170;510,380;535,380])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[510,255;530,255])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[680,370;750,370])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,355;535,355])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[575,370;610,370])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,250;585,250])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,240;530,240])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,250;750,250])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[670,120;750,120])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[475,110;530,110])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[570,120;595,120])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[870,240;960,240])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],[140,110;175,110])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1'].

set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Calcul champ magntique',13,'terrestre1']],...
		'BackGround',7,...
		'hide name',0,...
		'position',[405,84,540,156])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Angles']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Angles']],...
		'position',[350,135,355,140])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[660,150,665,155])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[285,110,305,130])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[615,110,635,130])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 3 composantes)']],...
		'position',[305,160,310,165])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[460,30,465,35])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],[545,120;610,120])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],[310,120;400,120])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite']],...
		'position',[365,463,565,537])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Mux1'],...
		'inputs','3',...
		'position',[225,459,265,541])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Entre des angles',13,'roulis et lacet']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Entre des angles',13,'roulis et lacet']],...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[390,175,395,180])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Vitesses',13,'inutiles']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Vitesses',13,'inutiles']],...
		'position',[190,210,195,215])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/in_1'],...
		'position',[40,265,60,285])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Gain'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Gain'],...
		'hide name',0,...
		'position',[735,238,760,262])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Demux'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Demux'],...
		'hide name',0,...
		'outputs','2',...
		'position',[500,223,535,332])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[445,240,475,315])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Roulis',13,'lacet']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Roulis',13,'lacet']],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[585,215,590,220])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Tangage'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Tangage'],...
		'position',[165,270,170,275])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Roulis'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Roulis'],...
		'position',[255,240,260,245])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Lacet'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Lacet'],...
		'position',[250,325,255,330])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Demux4'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Demux4'],...
		'outputs','[3 1 1 1]',...
		'position',[90,195,135,355])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Mux'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Mux'],...
		'inputs','2',...
		'position',[235,214,280,376])


%     Subsystem  'UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4'.

new_system([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4'],'Location',[31,157,323,338])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4/Mux'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4/Mux'],...
		'inputs','2',...
		'position',[175,57,205,133])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4/out_1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4/out_1'],...
		'position',[240,85,260,105])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4/Constant3'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4/Constant3'],...
		'hide name',0,...
		'Value','consigne_lacet',...
		'position',[25,104,130,126])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4/Constant1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4/Constant1'],...
		'hide name',0,...
		'Value','consigne_roulis',...
		'position',[25,62,135,88])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4'],[140,75;170,75])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4'],[135,115;170,115])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4'],[210,95;235,95])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4'],...
		'Mask Display','Consigne\nroulis(1) lacet(2)')


%     Finished composite block 'UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4'.

set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/UnNamed4'],...
		'hide name',0,...
		'position',[325,242,420,278])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Sortie roulis(1)',13,'lacet(2)']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Sortie roulis(1)',13,'lacet(2)']],...
		'position',[370,300,375,305])


%     Subsystem  'UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'.

new_system([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],'Location',[4,50,856,463])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Gain2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Gain2'],...
		'Gain','gain_roulis',...
		'position',[595,232,620,258])

add_block('built-in/Transfer Fcn',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Filtre passe bas',13,'roulis']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Filtre passe bas',13,'roulis']],...
		'Denominator','[1 1/0.8]',...
		'position',[680,220,740,270])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/out_1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/out_1'],...
		'position',[775,235,795,255])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Gain1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_ROULIS',...
		'position',[445,224,500,266])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/ROUE'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/ROUE'],...
		'hide name',0,...
		'position',[449,170,454,175])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Sum'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[535,137,565,353])

add_block('built-in/Derivative',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Derivative'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Derivative'],...
		'position',[365,225,410,265])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Intgrateur'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Intgrateur'],...
		'BackGround',7,...
		'Numerator','[I_PID_ROULIS]',...
		'Denominator','[1 0]',...
		'position',[350,294,435,336])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Gain'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_ROULIS',...
		'position',[370,156,445,194])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/gain 0 ou 1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/gain 0 ou 1'],...
		'Gain','0.5*0',...
		'position',[465,302,495,328])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Rappel proportionnel'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Rappel proportionnel'],...
		'position',[400,190,405,195])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/roulisref - roulis '])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/roulisref - roulis '],...
		'position',[280,135,285,140])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Rappel',13,'proportionnel']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/Rappel',13,'proportionnel']],...
		'ForeGround',1,...
		'position',[465,140,470,145])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/in_1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/in_1'],...
		'position',[265,165,285,185])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/PID ROULIS'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2/PID ROULIS'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[510,70,515,75])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[745,245;770,245])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[500,315;530,315])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[440,315;460,315])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[505,245;530,245])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[415,245;440,245])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[450,175;530,175])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[290,175;365,175])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[345,175;320,175;320,315;345,315])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[320,245;360,245])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[625,245;675,245])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],[570,245;590,245])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],...
		'Mask Display','PID ROULIS SEUL')


%     Finished composite block 'UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'.

set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem2'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[560,223,710,277])


%     Subsystem  'UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'.

new_system([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],'Location',[80,578,770,943])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Rappel',13,'proportionnel1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Rappel',13,'proportionnel1']],...
		'ForeGround',1,...
		'position',[315,75,320,80])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/lacet_ref - lacet  '])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/lacet_ref - lacet  '],...
		'position',[125,90,130,95])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Rappel proportionnel1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Rappel proportionnel1'],...
		'position',[245,145,250,150])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/gain 0 ou 2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/gain 0 ou 2'],...
		'Gain','0.5*0',...
		'position',[310,257,340,283])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Gain2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Gain2'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_LACET',...
		'position',[215,111,290,149])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Intgrateur1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Intgrateur1'],...
		'BackGround',7,...
		'Numerator','[I_PID_LACET]',...
		'Denominator','[1 0]',...
		'position',[210,249,280,291])

add_block('built-in/Derivative',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Derivative1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Derivative1'],...
		'position',[210,180,255,220])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Sum1'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[380,92,410,308])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/ROUE1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/ROUE1'],...
		'hide name',0,...
		'position',[294,125,299,130])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Gain3'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Gain3'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_LACET',...
		'position',[290,179,345,221])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/out_1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/out_1'],...
		'position',[580,190,600,210])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/in_1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/in_1'],...
		'position',[115,120,135,140])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Gain4'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Gain4'],...
		'Gain','gain_lacet',...
		'position',[440,187,465,213])

add_block('built-in/Transfer Fcn',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Filtre passe bas',13,'lacet']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/Filtre passe bas',13,'lacet']],...
		'Denominator','[1 1/0.8]',...
		'position',[485,175,545,225])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/PID LACET'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3/PID LACET'],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[335,20,340,25])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[140,130;210,130])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[190,130;165,130;165,270;205,270])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[165,200;205,200])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[295,130;375,130])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[260,200;285,200])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[350,200;375,200])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[285,270;305,270])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[345,270;375,270])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[550,200;575,200])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[470,200;480,200])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],[415,200;435,200])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],...
		'Mask Display','PID LACET SEUL')


%     Finished composite block 'UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'.

set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem3'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[560,283,710,337])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Consigne-Angles'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Consigne-Angles'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[370,330,375,335])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/PID teta'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/PID teta'],...
		'position',[640,430,645,435])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Mux3'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Mux3'],...
		'hide name',0,...
		'inputs','3',...
		'position',[850,308,880,412])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Gain4'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Gain4'],...
		'hide name',0,...
		'position',[730,373,755,397])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Sum2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[500,350,530,425])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Constant'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Constant'],...
		'hide name',0,...
		'Value','consigne_tangage',...
		'position',[330,360,440,380])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']],...
		'ForeGround',3,...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']],...
		'Font Weight','bold',...
		'Font Size',20)
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']],...
		'position',[515,30,520,35])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/out_2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/out_2'],...
		'Port','2',...
		'position',[905,585,925,605])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/out_3'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/out_3'],...
		'Port','3',...
		'position',[910,350,930,370])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/out_1'],...
		'position',[905,490,925,510])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Sortie des angles',13,'pour la suite']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Sortie des angles',13,'pour la suite']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[840,535,845,540])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Calcul des couples ',13,'de commandes ',13,'Cphi Cteta Cpsi']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Subsystem/Calcul des couples ',13,'de commandes ',13,'Cphi Cteta Cpsi']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[875,170,880,175])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','cpl_phi',...
		'buffer','points_trace',...
		'position',[815,242,865,258])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','cpl_psi',...
		'buffer','points_trace',...
		'position',[835,417,885,433])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ B axes satellite'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Champ B axes satellite'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[830,455,835,460])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/To Workspace2'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','cpl_teta',...
		'buffer','points_trace',...
		'position',[835,442,885,458])


%     Subsystem  'UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'.

new_system([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],'Location',[68,593,677,948])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Ecart teta_ref - teta'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Ecart teta_ref - teta'],...
		'position',[70,40,75,45])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Rappel proportionnel'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Rappel proportionnel'],...
		'position',[190,95,195,100])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/gain 0 ou 1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/gain 0 ou 1'],...
		'Gain','0',...
		'position',[255,207,285,233])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Gain'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_TANGAGE',...
		'position',[160,61,235,99])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/in_1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/in_1'],...
		'position',[55,70,75,90])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Intgrateur'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Intgrateur'],...
		'BackGround',7,...
		'Numerator','[I_PID_TANGAGE]',...
		'Denominator','[1 0]',...
		'position',[155,199,225,241])

add_block('built-in/Derivative',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Derivative'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Derivative'],...
		'position',[155,130,200,170])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Sum'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[325,42,355,258])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/ROUE'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/ROUE'],...
		'hide name',0,...
		'position',[239,75,244,80])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Gain1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_TANGAGE',...
		'position',[235,129,290,171])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Filtre passe bas'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Filtre passe bas'],...
		'Denominator','[1 1/0.8]',...
		'position',[455,125,515,175])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Gain2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/Gain2'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','gain_tangage',...
		'position',[375,129,430,171])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/commande_pid'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4/commande_pid'],...
		'position',[555,140,575,160])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[290,220;320,220])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[230,220;250,220])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[295,150;320,150])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[205,150;230,150])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[240,80;320,80])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[80,80;155,80])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[520,150;550,150])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[110,80;110,220;150,220])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[110,150;150,150])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[360,150;370,150])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],[435,150;450,150])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],...
		'Mask Display','P.I.D TANGAGE')


%     Finished composite block 'UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'.

set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem/Subsystem4'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[555,347,700,413])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[715,310;805,310;805,395;845,395])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[760,385;775,385;775,360;845,360])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[705,380;725,385])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[765,250;770,250;770,325;845,325])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[715,250;730,250])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[540,250;555,250])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[540,305;555,310])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[140,295;180,295;180,500;220,500])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[165,295;165,405;495,405])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[140,335;230,335])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[150,335;150,525;220,525])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[445,370;495,370])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[535,390;550,380])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[140,255;230,255])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[210,255;220,475])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[270,500;360,500])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[285,295;440,295])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[425,260;440,260])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[480,280;495,280])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[65,275;85,275])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[885,360;905,360])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[570,500;900,500])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[307,500;305,595;900,595])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[765,250;810,250])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[810,395;810,425;830,425])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],[775,385;775,450;830,450])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],...
		'Mask Display','CALCUL DES COUPLES PID\nSUR AXES DE MESURE\nDES ANGLES DE CARDAN')


%     Finished composite block 'UnNamed1/Subsystem4/Subsystem3/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Subsystem'],...
		'position',[50,269,230,371])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/REGULATION 2 MAGNECOUPLEURS ROULIS LACET + 1 ROUE TANGAGE'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/REGULATION 2 MAGNECOUPLEURS ROULIS LACET + 1 ROUE TANGAGE'],...
		'ForeGround',3,...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',20)
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/REGULATION 2 MAGNECOUPLEURS ROULIS LACET + 1 ROUE TANGAGE'],...
		'position',[660,35,665,40])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Sortie du couple total',13,'+',13,'Sortie du couple roue unidimensionnel']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Sortie du couple total',13,'+',13,'Sortie du couple roue unidimensionnel']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[605,80,610,85])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Cx Cy Cz'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Cx Cy Cz'],...
		'position',[420,515,425,520])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Demux5'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Demux5'],...
		'hide name',0,...
		'outputs','3',...
		'position',[440,354,480,456])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Constant2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[965,610,985,630])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem4/Subsystem3/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/MATLAB Fcn'],...
		'MATLAB Fcn','saturmm(u)',...
		'Output Width','3',...
		'position',[725,323,785,357])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Demux2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Demux2'],...
		'hide name',0,...
		'outputs','3',...
		'position',[805,301,845,379])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Champ magntique '])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Champ magntique '],...
		'position',[770,460,775,465])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/COUPLE ROUE',13,'DIMENSION 1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/COUPLE ROUE',13,'DIMENSION 1']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[1000,675,1005,680])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Outport1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Outport1'],...
		'Port','2',...
		'position',[1180,660,1200,680])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Outport'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Outport'],...
		'position',[1165,470,1185,490])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Sum'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Sum'],...
		'position',[1105,394,1130,561])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Moment cr par',13,'magntocoupleurs']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Moment cr par',13,'magntocoupleurs']],...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[1030,315,1035,320])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/Subsystem3/To Workspace7'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/To Workspace7'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','couple_roue',...
		'buffer','points_trace')
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/To Workspace7'],...
		'position',[720,559,825,591])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Constant1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[945,520,965,540])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux3'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux3'],...
		'hide name',0,...
		'inputs','3',...
		'position',[1015,507,1045,643])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem4/Subsystem3/MATLAB Fcn1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/MATLAB Fcn1'],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[1020,418,1080,452])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux2'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[970,365,1000,500])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/Subsystem3/To Workspace'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/To Workspace'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[905,383,950,397])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Gain'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Gain'],...
		'Gain','-1',...
		'position',[515,357,540,383])

add_block('built-in/Fcn',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Fcn'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Fcn'],...
		'Expr','1/u',...
		'position',[510,275,550,295])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Demux4'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Demux4'],...
		'hide name',0,...
		'outputs','3',...
		'position',[440,234,480,336])


%     Subsystem  ['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product'].

new_system([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/Product']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/Sum']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/in_2']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product']],[40,100;60,70])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product']],[150,65;180,65])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product'].

set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Inner',13,'Product']],...
		'position',[450,479,475,526])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Product2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Product2'],...
		'position',[615,477,645,513])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/mz'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/mz'],...
		'position',[625,335,630,340])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Cr'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Cr'],...
		'position',[625,450,630,455])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Product'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Product'],...
		'position',[610,277,640,313])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Product1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Product1'],...
		'position',[610,362,640,398])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux'],...
		'inputs','3',...
		'position',[675,273,705,407])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Moments magntiques',13,'des bobines']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Moments magntiques',13,'des bobines']],...
		'position',[755,230,760,235])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Subsystem3/Limiteur de',13,'moments magntiques',13,'et de couple roue']])
set_param([sys,'/',['UnNamed1/Subsystem4/Subsystem3/Limiteur de',13,'moments magntiques',13,'et de couple roue']],...
		'position',[800,400,805,405])

add_block('built-in/Constant',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Constant'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Constant'],...
		'hide name',0,...
		'Value','0',...
		'position',[845,285,865,305])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[905,228,935,362])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/Subsystem3/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[885,197,935,213])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem4/Subsystem3/MATLAB Fcn2'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/MATLAB Fcn2'],...
		'MATLAB Fcn','CpidToCm(u)',...
		'Output Width','3',...
		'position',[325,323,385,357])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Champ magntique'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Champ magntique'],...
		'position',[335,260,340,265])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux4'])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3/Mux4'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[260,302,300,373])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[40,320;45,320])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[235,320;255,320])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[235,355;255,355])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[235,285;435,285])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[485,285;505,285])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[485,440;585,440;585,305;605,305])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[555,285;605,285])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[485,370;510,370])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[545,370;605,370])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[555,285;555,390;605,390])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[390,340;425,340;435,405])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[405,340;405,515;445,515])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[420,285;420,490;445,490])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[480,505;610,505])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[555,390;555,485;610,485])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[710,340;720,340])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[790,340;800,340])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[645,380;655,380;655,340;670,340])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[650,495;655,495;655,385;670,385])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[850,340;900,340])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[850,315;880,315;880,250;900,250])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[870,295;900,295])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[865,315;865,205;880,205])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[885,340;885,390;900,390])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[1005,435;1015,435])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[940,295;955,295;965,400])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[420,465;965,465])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[970,530;1010,530])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[990,620;1010,620])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[850,365;860,365;860,575;1010,575])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[860,575;830,575])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[1085,435;1100,435])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[1050,575;1075,575;1075,520;1100,520])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[1135,480;1160,480])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[865,575;865,670;1175,670])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[305,340;320,340])
add_line([sys,'/','UnNamed1/Subsystem4/Subsystem3'],[645,295;670,295])
set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3'],...
		'Mask Display','COMMANDE 2 AXES ROULIS-LACET\n\nAVEC 2 BOBINES ROULIS-LACET\n\nCOMMANDE TANGAGE SEUL PAR ROUE')


%     Finished composite block 'UnNamed1/Subsystem4/Subsystem3'.

set_param([sys,'/','UnNamed1/Subsystem4/Subsystem3'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[385,95,730,195])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/out_1'])
set_param([sys,'/','UnNamed1/Subsystem4/out_1'],...
		'position',[815,110,835,130])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem4/Couple total'])
set_param([sys,'/','UnNamed1/Subsystem4/Couple total'],...
		'position',[885,105,890,110])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem4/Couple roue',13,'unidimensionnel']])
set_param([sys,'/',['UnNamed1/Subsystem4/Couple roue',13,'unidimensionnel']],...
		'position',[900,150,905,155])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem4/out_2'])
set_param([sys,'/','UnNamed1/Subsystem4/out_2'],...
		'Port','2',...
		'position',[815,160,835,180])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem4/Demux2'])
set_param([sys,'/','UnNamed1/Subsystem4/Demux2'],...
		'outputs','3',...
		'position',[340,230,385,340])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem4/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[430,240,490,260])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem4/To Workspace2'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[430,275,490,295])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem4/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem4/To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[425,310,490,330])
add_line([sys,'/','UnNamed1/Subsystem4'],[365,145;380,145])
add_line([sys,'/','UnNamed1/Subsystem4'],[190,170;320,170])
add_line([sys,'/','UnNamed1/Subsystem4'],[105,170;120,170])
add_line([sys,'/','UnNamed1/Subsystem4'],[40,145;50,145])
add_line([sys,'/','UnNamed1/Subsystem4'],[220,170;230,115])
add_line([sys,'/','UnNamed1/Subsystem4'],[300,115;320,115])
add_line([sys,'/','UnNamed1/Subsystem4'],[735,120;810,120])
add_line([sys,'/','UnNamed1/Subsystem4'],[735,170;810,170])
add_line([sys,'/','UnNamed1/Subsystem4'],[390,250;425,250])
add_line([sys,'/','UnNamed1/Subsystem4'],[390,285;425,285])
add_line([sys,'/','UnNamed1/Subsystem4'],[390,320;420,320])
add_line([sys,'/','UnNamed1/Subsystem4'],[300,115;300,285;335,285])
set_param([sys,'/','UnNamed1/Subsystem4'],...
		'Mask Display','ACQUISITION FINALE\nAPRES DETUMBLING')


%     Finished composite block 'UnNamed1/Subsystem4'.

set_param([sys,'/','UnNamed1/Subsystem4'],...
		'hide name',0,...
		'position',[145,427,375,518])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain7'])
set_param([sys,'/','UnNamed1/Gain7'],...
		'hide name',0,...
		'position',[420,532,445,558])


%     Subsystem  'UnNamed1/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem'],'Location',[305,703,1157,1003])

add_block('built-in/Scope',[sys,'/','UnNamed1/Subsystem/Scope'])
set_param([sys,'/','UnNamed1/Subsystem/Scope'],...
		'Vgain','2000.000000',...
		'Hgain','4000.000000',...
		'Vmax','4000.000000',...
		'Hmax','8000.000000',...
		'Window',[39,580,681,1020],...
		'position',[630,95,660,125])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']],...
		'Gain','-1',...
		'position',[115,122,145,148])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Gain3'])
set_param([sys,'/','UnNamed1/Subsystem/Gain3'],...
		'Gain','30/pi',...
		'position',[445,118,470,152])

add_block('built-in/Integrator',[sys,'/','UnNamed1/Subsystem/Integrator2'])
set_param([sys,'/','UnNamed1/Subsystem/Integrator2'],...
		'BackGround',7,...
		'Initial','rotation_initiale*0',...
		'position',[325,113,370,157])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/To Workspace6'])
set_param([sys,'/','UnNamed1/Subsystem/To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vitesseroue',...
		'buffer','points_trace',...
		'position',[455,179,600,211])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem/To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[515,120,595,150])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Vitesse roue ',13,'en rd//s']])
set_param([sys,'/',['UnNamed1/Subsystem/Vitesse roue ',13,'en rd//s']],...
		'position',[520,210,525,215])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Gain5'])
set_param([sys,'/','UnNamed1/Subsystem/Gain5'],...
		'BackGround',7,...
		'Gain','1/jroue',...
		'position',[240,115,275,155])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/in_1'],...
		'position',[20,125,40,145])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Vitesse roue',13,'en tours//mn']])
set_param([sys,'/',['UnNamed1/Subsystem/Vitesse roue',13,'en tours//mn']],...
		'position',[455,70,460,75])
add_line([sys,'/','UnNamed1/Subsystem'],[475,135;510,135])
add_line([sys,'/','UnNamed1/Subsystem'],[490,135;490,110;625,110])
add_line([sys,'/','UnNamed1/Subsystem'],[150,135;235,135])
add_line([sys,'/','UnNamed1/Subsystem'],[45,135;110,135])
add_line([sys,'/','UnNamed1/Subsystem'],[280,135;320,135])
add_line([sys,'/','UnNamed1/Subsystem'],[375,135;440,135])
add_line([sys,'/','UnNamed1/Subsystem'],[395,135;395,195;450,195])
set_param([sys,'/','UnNamed1/Subsystem'],...
		'Mask Display','EVOLUTION DE LA\nVITESSE DE LA ROUE')


%     Finished composite block 'UnNamed1/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[465,514,610,576])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain2'])
set_param([sys,'/','UnNamed1/Gain2'],...
		'hide name',0,...
		'position',[435,437,460,463])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain'])
set_param([sys,'/','UnNamed1/Gain'],...
		'hide name',0,...
		'position',[510,352,535,378])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain5'])
set_param([sys,'/','UnNamed1/Gain5'],...
		'hide name',0,...
		'position',[890,222,915,248])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m2'])
set_param([sys,'/','UnNamed1/magneto.m2'],...
		'hide name',0,...
		'MATLAB Fcn','jw_rotot(u)',...
		'Output Width','3',...
		'Mask Display','Participation\nde la roue',...
		'position',[720,206,855,264])

add_block('built-in/Note',[sys,'/',['UnNamed1/Somme des couples',13,'externes']])
set_param([sys,'/',['UnNamed1/Somme des couples',13,'externes']],...
		'position',[665,295,670,300])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression ',13,'possible de la roue']])
set_param([sys,'/',['UnNamed1/Suppression ',13,'possible de la roue']],...
		'position',[925,180,930,185])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],'Location',[4,50,1267,977])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[410,30,415,35])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'position',[255,340,480,390])

add_block('built-in/Mux',[sys,'/','UnNamed1/Mux'])
set_param([sys,'/','UnNamed1/Mux'],...
		'inputs','[1 3]',...
		'position',[630,216,660,249])

add_block('built-in/Constant',[sys,'/','UnNamed1/Constant'])
set_param([sys,'/','UnNamed1/Constant'],...
		'Value','0',...
		'position',[530,190,550,210])
add_line([sys,'/','UnNamed1'],[210,160;355,160])
add_line([sys,'/','UnNamed1'],[1055,260;1075,260])
add_line([sys,'/','UnNamed1'],[1110,260;1140,260])
add_line([sys,'/','UnNamed1'],[80,190;155,190])
add_line([sys,'/','UnNamed1'],[500,160;1025,160])
add_line([sys,'/','UnNamed1'],[485,365;505,365])
add_line([sys,'/','UnNamed1'],[120,190;120,365;250,365])
add_line([sys,'/','UnNamed1'],[790,405;840,405])
add_line([sys,'/','UnNamed1'],[950,405;965,405])
add_line([sys,'/','UnNamed1'],[1000,405;1005,405;1005,360;1025,360])
add_line([sys,'/','UnNamed1'],[860,235;885,235])
add_line([sys,'/','UnNamed1'],[920,235;940,235;940,260;1025,260])
add_line([sys,'/','UnNamed1'],[120,330;120,475;140,475])
add_line([sys,'/','UnNamed1'],[380,495;380,545;415,545])
add_line([sys,'/','UnNamed1'],[380,450;430,450])
add_line([sys,'/','UnNamed1'],[450,545;460,545])
add_line([sys,'/','UnNamed1'],[465,450;755,450])
add_line([sys,'/','UnNamed1'],[540,365;755,360])
add_line([sys,'/','UnNamed1'],[717,450;715,570;805,570])
add_line([sys,'/','UnNamed1'],[860,535;895,535])
add_line([sys,'/','UnNamed1'],[860,570;895,570])
add_line([sys,'/','UnNamed1'],[860,605;890,605])
add_line([sys,'/','UnNamed1'],[665,235;715,235])
add_line([sys,'/','UnNamed1'],[285,160;285,240;625,240])
add_line([sys,'/','UnNamed1'],[555,200;595,200;595,225;625,225])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[145,248,370,332])
add_line(sys,[745,365;765,365;765,520;55,520;55,435;135,435])
add_line(sys,[580,365;635,365])
add_line(sys,[375,290;510,290])
add_line(sys,[360,435;510,435])
add_line(sys,[765,365;765,300;840,300])
add_line(sys,[615,365;615,335;840,335])
add_line(sys,[55,435;55,290;140,290])
add_line(sys,[765,300;765,295;725,295])
add_line(sys,[805,300;815,230])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
