function [ret,x0,str,ts,xts]=inutile4(t,x,u,flag);
%INUTILE4	is the M-file description of the SIMULINK system named INUTILE4.
%	The block-diagram can be displayed by typing: INUTILE4.
%
%	SYS=INUTILE4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes INUTILE4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling INUTILE4 with a FLAG of zero:
%	[SIZES]=INUTILE4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[6,51,1259,955])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '4700')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '0.2')
set_param(sys,'Max step size', '0.5')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time algorithm','')

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[530,410,535,415])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[535,270,540,275])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[-0.0024 0.0040 -0.0029 0.2908 -0.4166 0.8205 0.2620]',...
		'position',[640,339,740,391])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[515,219,575,506])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[430,435,435,440])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[440,255,445,260])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[385,500,390,505])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[200,525,205,530])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[610,520,615,525])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[430,585,435,590])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,50,1012,686])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[330,710,560,796])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[85,635,285,701])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[800,330,805,335])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[429,285,1217,578])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt',13,'suivant angles et vitesses']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt',13,'suivant angles et vitesses']],...
		'MATLAB Fcn','stopacqf(u)',...
		'Output Width','1',...
		'position',[205,63,265,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[500,63,540,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[520,27,570,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'position',[335,63,415,97])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/Sorties angles et',13,'vitesses angulaires']])
set_param([sys,'/',['Subsystem2/Sorties angles et',13,'vitesses angulaires']],...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'position',[85,63,145,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[410,180,415,185])
add_line([sys,'/','Subsystem2'],[270,80;330,80])
add_line([sys,'/','Subsystem2'],[420,80;495,80])
add_line([sys,'/','Subsystem2'],[450,80;450,35;515,35])
add_line([sys,'/','Subsystem2'],[40,80;80,80])
add_line([sys,'/','Subsystem2'],[150,80;200,80])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[635,268,720,322])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[765,265,770,270])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\nmoments magntiques \nmx, my, mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[325,640,575,701])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r);grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[80,715,285,776])


%     Subsystem  'Extras15'.

new_system([sys,'/','Extras15'])
set_param([sys,'/','Extras15'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras15'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nphi teta psi (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,v_roulis,temps,v_tangage,temps,v_lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras15'.

set_param([sys,'/','Extras15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[85,790,290,851])

add_block('built-in/Note',[sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'Avec champ magntique puls ',13,'']])
set_param([sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'Avec champ magntique puls ',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[605,90,610,95])

add_block('built-in/Note',[sys,'/',['SIMULATION regacqGP drive de regderB7 et de regderb6.m )  Intgration initialise par initpqrQ.mat',13,'']])
set_param([sys,'/',['SIMULATION regacqGP drive de regderB7 et de regderb6.m )  Intgration initialise par initpqrQ.mat',13,'']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18)
set_param([sys,'/',['SIMULATION regacqGP drive de regderB7 et de regderb6.m )  Intgration initialise par initpqrQ.mat',13,'']],...
		'position',[660,55,665,60])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCphi, Cteta,Cpsi',...
		'Mask Dialogue','eval(''plot(temps,cpl_phi,temps,cpl_teta,temps,cpl_psi);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,705,770,771])


%     Subsystem  'Extras14'.

new_system([sys,'/','Extras14'])
set_param([sys,'/','Extras14'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras14'],...
		'Mask Display','Couples de\ncommande  (Nm)\nCx, Cy,Cz',...
		'Mask Dialogue','eval(''plot(temps,Cx,temps,Cy,temps,Cz);grid;figure(gcf)'')')


%     Finished composite block 'Extras14'.

set_param([sys,'/','Extras14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,785,770,851])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Voir la courbe\n\nenergie relative (J)',...
		'Mask Dialogue','eval(''plot(temps,energie_relative);grid;figure(gcf)'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[340,800,540,856])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir les courbes\n champ By satellite\net de BY orbitale',...
		'Mask Dialogue','eval(''plot(temps,By,temps,BY);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,635,765,696])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Voir la commande \navant le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_avant);grid;figure(gcf)'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[805,640,1005,706])


%     Subsystem  'Extras18'.

new_system([sys,'/','Extras18'])
set_param([sys,'/','Extras18'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras18'],...
		'Mask Display','Voir la commande \napres le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_apres);grid;figure(gcf)'')')


%     Finished composite block 'Extras18'.

set_param([sys,'/','Extras18'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[805,715,1005,781])


%     Subsystem  'Extras20'.

new_system([sys,'/','Extras20'])
set_param([sys,'/','Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras20'],...
		'Mask Display','Diffrence des \nciommandes haches\n avant - apres',...
		'Mask Dialogue','eval(''plot(temps,com_avant-com_apres);grid;figure(gcf)'')')


%     Finished composite block 'Extras20'.

set_param([sys,'/','Extras20'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[810,790,1010,856])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1045,630,1200,696])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1050,710,1205,776])

add_block('built-in/Note',[sys,'/',['',13,'ACQUISITION FINE EN PHASE FINALE DU DETUMBLING APRES "Bpoint" ']])
set_param([sys,'/',['',13,'ACQUISITION FINE EN PHASE FINALE DU DETUMBLING APRES "Bpoint" ']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[708,0,713,5])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[123,285,1228,670])

add_block('built-in/Note',[sys,'/','Subsystem3/Transmission des valeurs finales'])
set_param([sys,'/','Subsystem3/Transmission des valeurs finales'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,0,565,5])

add_block('built-in/Clock',[sys,'/','Subsystem3/Clock'])
set_param([sys,'/','Subsystem3/Clock'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[95,43,130,77])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux1'])
set_param([sys,'/','Subsystem3/Mux1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[280,165,305,225])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux'])
set_param([sys,'/','Subsystem3/Demux'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'outputs','[3 3]',...
		'position',[175,161,215,194])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/MATLAB Fcn'])
set_param([sys,'/','Subsystem3/MATLAB Fcn'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'position',[85,163,145,197])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'position',[25,170,45,190])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux'])
set_param([sys,'/','Subsystem3/Mux'],...
		'inputs','[1 6]',...
		'position',[460,93,495,162])

add_block('built-in/To File',[sys,'/','Subsystem3/To File1'])
set_param([sys,'/','Subsystem3/To File1'],...
		'hide name',0,...
		'File name','tmc_init.mat',...
		'Matrix name','cond_init',...
		'position',[585,114,690,146])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace'])
set_param([sys,'/','Subsystem3/To Workspace'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','init_tmc',...
		'buffer','1',...
		'position',[490,183,540,207])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace1'])
set_param([sys,'/','Subsystem3/To Workspace1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_init_tmc',...
		'buffer','1',...
		'position',[450,48,555,72])

add_block('built-in/To File',[sys,'/','Subsystem3/To File'])
set_param([sys,'/','Subsystem3/To File'],...
		'hide name',0,...
		'File name','initpqrQ.mat',...
		'Matrix name','initpqrQ',...
		'position',[575,252,715,288])

add_block('built-in/Note',[sys,'/',['Subsystem3/Transmission ',13,'au mode fin quaternion']])
set_param([sys,'/',['Subsystem3/Transmission ',13,'au mode fin quaternion']],...
		'position',[805,250,810,255])

add_block('built-in/Note',[sys,'/',['Subsystem3/Transmission au mode fin',13,'trait TMC']])
set_param([sys,'/',['Subsystem3/Transmission au mode fin',13,'trait TMC']],...
		'position',[790,110,795,115])
add_line([sys,'/','Subsystem3'],[135,60;445,60])
add_line([sys,'/','Subsystem3'],[310,195;485,195])
add_line([sys,'/','Subsystem3'],[220,185;235,185;235,180;275,180])
add_line([sys,'/','Subsystem3'],[220,170;250,170;250,210;275,210])
add_line([sys,'/','Subsystem3'],[150,180;170,180])
add_line([sys,'/','Subsystem3'],[50,180;80,180])
add_line([sys,'/','Subsystem3'],[50,180;55,180;55,270;570,270])
add_line([sys,'/','Subsystem3'],[350,60;350,110;455,110])
add_line([sys,'/','Subsystem3'],[355,195;355,145;455,145])
add_line([sys,'/','Subsystem3'],[500,130;580,130])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','SORTIES DES CONDITIONS\nFINALES DEVANT SERVIR\nDE CONDITIONS INITIALES\nA LA FUTURE SIMULATION')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[845,372,1090,458])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[1130,398,1165,432])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem1/d) Lancer la simulation'])
set_param([sys,'/','Subsystem1/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem1/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem1/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem1/b) '])
set_param([sys,'/','Subsystem1/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem1/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem1/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation principale c''est ACQ_DAT3.M']])
set_param([sys,'/',['Subsystem1/Pour la simulation principale c''est ACQ_DAT3.M']],...
		'Font Size',14,...
		'position',[405,125,410,130])

add_block('built-in/Note',[sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,90,500,95])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','LIRE LES EXPLICATIONS')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[160,880,510,916])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance acq_dat6.m']])
set_param([sys,'/',['L''initialisation',13,' lance acq_dat6.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[965,540,970,545])


%     Subsystem  'Extras19'.

new_system([sys,'/','Extras19'])
set_param([sys,'/','Extras19'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras19'],...
		'Mask Display','LANCER\n\n LE MODE FIN',...
		'Mask Dialogue','eval(''regdesat'')')


%     Finished composite block 'Extras19'.

set_param([sys,'/','Extras19'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1055,790,1205,861])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''acq_dat6'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[850,465,1085,536])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[48,78,1231,917])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/Fcn',[sys,'/','Subsystem/Fcn'])
set_param([sys,'/','Subsystem/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[720,325,760,345])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusq2',...
		'buffer','points_trace',...
		'position',[805,325,875,345])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/To File',[sys,'/','Subsystem/To File3'])
set_param([sys,'/','Subsystem/To File3'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','temps',...
		'position',[1115,547,1205,593])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace10'])
set_param([sys,'/','Subsystem/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[800,272,900,298])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[935,624,1020,656])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[915,575,920,580])


%     Subsystem  ['Subsystem/Vitesses angulaires',13,'rd//s1'].

new_system([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1']],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1/x']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1/x']],...
		'position',[65,55,85,75])
add_line([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1']],[90,65;125,65])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1']],...
		'Mask Entries','1000\/-0.02\/0.02\/''y-/m--/c-./w:/g*/ro/b+''\/')


%     Finished composite block ['Subsystem/Vitesses angulaires',13,'rd//s1'].

set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s1']],...
		'orientation',2,...
		'BackGround',2,...
		'position',[340,192,450,228])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[785,452,810,478])


%     Subsystem  'Subsystem/Angles en degrs1'.

new_system([sys,'/','Subsystem/Angles en degrs1'])
set_param([sys,'/','Subsystem/Angles en degrs1'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Angles en degrs1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Angles en degrs1/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Subsystem/Angles en degrs1/x'])
set_param([sys,'/','Subsystem/Angles en degrs1/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Subsystem/Angles en degrs1'],[90,65;125,65])
set_param([sys,'/','Subsystem/Angles en degrs1'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Subsystem/Angles en degrs1'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Subsystem/Angles en degrs1'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Subsystem/Angles en degrs1'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Subsystem/Angles en degrs1'],...
		'Mask Entries','1000\/-200\/200\/''y-/m--/c-./w:/g*/ro/b+''\/')


%     Finished composite block 'Subsystem/Angles en degrs1'.

set_param([sys,'/','Subsystem/Angles en degrs1'],...
		'orientation',2,...
		'BackGround',2,...
		'position',[700,517,810,553])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace18'])
set_param([sys,'/','Subsystem/To Workspace18'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie_relative',...
		'buffer','points_trace',...
		'position',[1075,737,1210,763])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn5'])
set_param([sys,'/','Subsystem/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[960,731,1040,769])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn6'])
set_param([sys,'/','Subsystem/MATLAB Fcn6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','energie(u)',...
		'Output Width','1',...
		'position',[720,361,800,399])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace19'])
set_param([sys,'/','Subsystem/To Workspace19'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[820,370,890,390])
add_line([sys,'/','Subsystem'],[425,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;960,535])
add_line([sys,'/','Subsystem'],[525,380;660,380;660,335;715,335])
add_line([sys,'/','Subsystem'],[765,335;800,335])
add_line([sys,'/','Subsystem'],[660,335;660,285;795,285])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;930,640])
add_line([sys,'/','Subsystem'],[765,465;780,465])
add_line([sys,'/','Subsystem'],[815,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem'],[930,535;930,570;1110,570])
add_line([sys,'/','Subsystem'],[525,380;550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[550,210;455,210])
add_line([sys,'/','Subsystem'],[840,465;840,535;815,535])
add_line([sys,'/','Subsystem'],[1045,750;1070,750])
add_line([sys,'/','Subsystem'],[920,640;920,750;955,750])
add_line([sys,'/','Subsystem'],[805,380;815,380])
add_line([sys,'/','Subsystem'],[660,380;715,380])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[830,275,1065,350])


%     Subsystem  'F(X,t) pour la rotation'.

new_system([sys,'/','F(X,t) pour la rotation'])
set_param([sys,'/','F(X,t) pour la rotation'],'Location',[4,50,1267,947])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/F(X,t) POUR LA DERIVEE DE LA ROTATION ABSOLUE'])
set_param([sys,'/','F(X,t) pour la rotation/F(X,t) POUR LA DERIVEE DE LA ROTATION ABSOLUE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',24,...
		'position',[655,15,660,20])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Mux'])
set_param([sys,'/','F(X,t) pour la rotation/Mux'],...
		'inputs','[1 7]',...
		'position',[615,530,650,650])


%     Subsystem  'F(X,t) pour la rotation/Subsystem'.

new_system([sys,'/','F(X,t) pour la rotation/Subsystem'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem'],'Location',[303,541,1155,841])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']],...
		'Gain','-1',...
		'position',[115,122,145,148])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Subsystem/Gain3'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/Gain3'],...
		'Gain','30/pi',...
		'position',[445,118,470,152])

add_block('built-in/Integrator',[sys,'/','F(X,t) pour la rotation/Subsystem/Integrator2'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/Integrator2'],...
		'BackGround',7,...
		'Initial','rotation_initiale*0',...
		'position',[325,113,370,157])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Subsystem/To Workspace6'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vitesseroue',...
		'buffer','points_trace',...
		'position',[455,179,600,211])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Subsystem/To Workspace5'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[515,120,595,150])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse roue ',13,'en rd//s']])
set_param([sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse roue ',13,'en rd//s']],...
		'position',[520,210,525,215])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Subsystem/Gain5'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/Gain5'],...
		'BackGround',7,...
		'Gain','1/J',...
		'position',[240,115,275,155])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Subsystem/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/in_1'],...
		'position',[20,125,40,145])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse roue',13,'en tours//mn']])
set_param([sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse roue',13,'en tours//mn']],...
		'position',[490,70,495,75])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Subsystem/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/out_1'],...
		'position',[670,230,690,250])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse de',13,'la roue']])
set_param([sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse de',13,'la roue']],...
		'position',[730,220,735,225])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[475,135;510,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[150,135;235,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[45,135;110,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[280,135;320,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[375,135;440,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[395,135;395,195;450,195])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[395,195;395,240;665,240])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem'],...
		'Mask Display','EVOLUTION DE LA\nVITESSE DE LA ROUE')


%     Finished composite block 'F(X,t) pour la rotation/Subsystem'.

set_param([sys,'/','F(X,t) pour la rotation/Subsystem'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[430,529,575,591])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain7'])
set_param([sys,'/','F(X,t) pour la rotation/Gain7'],...
		'hide name',0,...
		'position',[385,547,410,573])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],'Location',[5,51,955,501])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Angles  rd']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Angles  rd']],...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[125,153,185,187])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Demux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Demux1']],...
		'outputs','[3 4]',...
		'position',[55,88,100,197])

add_block('built-in/Derivative',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Derivative']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Derivative']],...
		'position',[235,91,295,139])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Mux']],...
		'inputs','[3 3]',...
		'position',[325,85,360,200])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],'Location',[4,51,1267,925])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/REGULATION 2 MAGNECOUPLEURS ROULIS LACET + 1 ROUE TANGAGE']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/REGULATION 2 MAGNECOUPLEURS ROULIS LACET + 1 ROUE TANGAGE']],...
		'ForeGround',3,...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/REGULATION 2 MAGNECOUPLEURS ROULIS LACET + 1 ROUE TANGAGE']],...
		'Font Size',20,...
		'position',[660,35,665,40])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Sortie du couple total',13,'+',13,'Sortie du couple roue unidimensionnel']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Sortie du couple total',13,'+',13,'Sortie du couple roue unidimensionnel']],...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Sortie du couple total',13,'+',13,'Sortie du couple roue unidimensionnel']],...
		'Font Size',20,...
		'position',[605,80,610,85])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Cx Cy Cz']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Cx Cy Cz']],...
		'position',[420,515,425,520])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Demux5']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Demux5']],...
		'hide name',0,...
		'outputs','3',...
		'position',[440,354,480,456])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Constant2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Constant2']],...
		'hide name',0,...
		'Value','0',...
		'position',[965,610,985,630])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/MATLAB Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/MATLAB Fcn']],...
		'MATLAB Fcn','saturmm(u)',...
		'Output Width','3',...
		'position',[725,323,785,357])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Demux2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Demux2']],...
		'hide name',0,...
		'outputs','3',...
		'position',[805,301,845,379])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/COUPLE ROUE',13,'DIMENSION 1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/COUPLE ROUE',13,'DIMENSION 1']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[1000,675,1005,680])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Outport1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Outport1']],...
		'Port','2',...
		'position',[1180,660,1200,680])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Outport']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Outport']],...
		'position',[1165,470,1185,490])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Sum']],...
		'position',[1105,394,1130,561])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Moment cr par',13,'magntocoupleurs']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Moment cr par',13,'magntocoupleurs']],...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[1030,315,1035,320])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/To Workspace7']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/To Workspace7']],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','couple_roue')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/To Workspace7']],...
		'buffer','points_trace',...
		'position',[720,559,825,591])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Constant1']],...
		'hide name',0,...
		'Value','0',...
		'position',[945,520,965,540])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[1015,507,1045,643])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/MATLAB Fcn1']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[1020,418,1080,452])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[970,365,1000,500])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/To Workspace']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/To Workspace']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[905,383,950,397])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Gain']],...
		'Gain','-1',...
		'position',[515,357,540,383])

add_block('built-in/Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Fcn']],...
		'Expr','1/u',...
		'position',[510,275,550,295])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Demux4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Demux4']],...
		'hide name',0,...
		'outputs','3',...
		'position',[440,234,480,336])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/Product']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product']],[40,100;60,70])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product']],[150,65;180,65])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Inner',13,'Product']],...
		'position',[450,479,475,526])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Product2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Product2']],...
		'position',[615,477,645,513])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/mz']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/mz']],...
		'position',[625,335,630,340])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Cr']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Cr']],...
		'position',[625,450,630,455])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Product']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Product']],...
		'position',[610,277,640,313])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Product1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Product1']],...
		'position',[610,362,640,398])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux']],...
		'inputs','3',...
		'position',[675,273,705,407])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Moments magntiques',13,'des bobines']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Moments magntiques',13,'des bobines']],...
		'position',[755,230,760,235])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Limiteur de',13,'moments magntiques',13,'et de couple roue']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Limiteur de',13,'moments magntiques',13,'et de couple roue']],...
		'position',[800,400,805,405])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Constant']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Constant']],...
		'hide name',0,...
		'Value','0',...
		'position',[845,285,865,305])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux1']],...
		'hide name',0,...
		'inputs','3',...
		'position',[905,228,935,362])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/To Workspace1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/To Workspace1']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[885,197,935,213])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/MATLAB Fcn2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/MATLAB Fcn2']],...
		'MATLAB Fcn','CpidToCm(u)',...
		'Output Width','3',...
		'position',[325,323,385,357])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Mux4']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[260,302,300,373])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],'Location',[-32000,-32000,-31840,-31969])
open_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Mux1']],...
		'inputs','3',...
		'position',[225,459,265,541])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/in_1']],...
		'position',[40,265,60,285])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Roulis',13,'lacet']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Roulis',13,'lacet']],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Roulis',13,'lacet']],...
		'position',[585,215,590,220])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Tangage']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Tangage']],...
		'position',[165,270,170,275])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Roulis']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Roulis']],...
		'position',[255,240,260,245])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Lacet']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Lacet']],...
		'position',[250,325,255,330])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Demux4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Demux4']],...
		'outputs','[3 1 1 1]',...
		'position',[90,195,135,355])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Mux']],...
		'inputs','2',...
		'position',[235,214,280,376])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']],...
		'Font Size',20)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/CALCUL DES COUPLES DE COMMANDE PID ',13,'SUR LES AXES SQPECIFIQUES DE MESURE DES ANGLES',13,'( Signe - de rappel  incorpor )']],...
		'position',[515,30,520,35])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1']],'Location',[195,367,1041,836])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Equateur au temps 0 s']],...
		'position',[215,30,220,35])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Vecteur d''tat ',13,'( 3 composantes)']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Vecteur d''tat ',13,'( 3 composantes)']],...
		'position',[60,160,65,165])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Angles']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Angles']],...
		'position',[105,135,110,140])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/in_1']],...
		'position',[45,115,65,135])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],'Location',[27,258,1102,698])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/in_2']],...
		'position',[120,160,140,180])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Vecteur',13,'d''tat',13,'(angles)']],...
		'position',[273,165,278,170])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'MATLAB Fcn','champmgn(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn3']],...
		'position',[180,85,355,135])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Temps']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Temps']],...
		'position',[85,65,90,70])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[305,25,310,30])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'MATLAB Fcn','u(1:3)''*u(4:6)')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'Output Width','1')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn1']],...
		'position',[590,234,665,266])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'MATLAB Fcn','u(1:3)''*u(4:6)')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'Output Width','1')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn']],...
		'position',[600,104,665,136])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Angles']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Angles']],...
		'position',[439,145,444,150])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'hide name',0,...
		'inputs','[3 3]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux2']],...
		'position',[540,344,570,391])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'hide name',0,...
		'A','[]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'B','[]',...
		'C','[]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'D','K',...
		'Mask Display','Axe z')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Type','Matrix gain')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Translate','K = @1;')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'Mask Entries','[0 -1 0 ;1 0 0 ;0 0 0]\/')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.3']],...
		'position',[415,338,470,372])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'MATLAB Fcn','u(1:3)''*u(4:6)')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'Output Width','1')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/MATLAB Fcn2']],...
		'position',[615,349,675,391])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sum2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sum2']],...
		'position',[755,339,790,381])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sum1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sum1']],...
		'position',[755,220,770,260])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux1']],...
		'position',[535,230,565,265])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'hide name',0,...
		'A','[]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'B','[]',...
		'C','[]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'D','K',...
		'Mask Display','Axe y')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Type','Matrix gain')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Translate','K = @1;')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'Mask Entries','[0 0 1;0 0 0;-1 0 0]\/')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.2']],...
		'position',[415,223,470,257])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sum']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sum']],...
		'position',[755,95,775,130])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/BX']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/BX']],...
		'position',[740,75,745,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/BY']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/BY']],...
		'position',[730,205,735,210])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'hide name',0,...
		'inputs','3')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux3']],...
		'position',[820,220,865,260])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/By']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/By']],...
		'position',[784,215,789,220])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux']],...
		'hide name',0,...
		'inputs','[3 3]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Mux']],...
		'position',[535,100,565,135])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Demux']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Demux']],...
		'outputs','3')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Demux']],...
		'position',[520,44,580,76])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'hide name',0,...
		'A','[]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'B','[]',...
		'C','[]',...
		'D','K')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Display','Axe x')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Type','Matrix gain')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Translate','K = @1;')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'Mask Entries','[0 0 0;0 0 -1;0 1 0]\/')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Matrix gain.']],...
		'position',[415,93,470,127])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/out_1']],...
		'position',[965,230,985,250])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[910,170,915,175])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/BZ']],...
		'position',[715,325,720,330])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Bz']],...
		'position',[804,290,809,295])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Bx']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Bx']],...
		'position',[804,170,809,175])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Clock']],...
		'position',[35,100,55,120])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/out_2']],...
		'Port','2')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/out_2']],...
		'position',[960,405,980,425])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sortie du temps simulation']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1/Sortie du temps simulation']],...
		'position',[960,375,965,380])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[60,110;175,110])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[870,240;960,240])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[570,120;595,120])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[475,110;530,110])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[670,120;750,120])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[670,250;750,250])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[475,240;530,240])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[570,250;585,250])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[575,370;610,370])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[475,355;535,355])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[680,370;750,370])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[145,170;510,170;510,125;530,125])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[510,170;510,380;535,380])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[510,255;530,255])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[360,110;410,110])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[380,110;380,355;410,355])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[380,240;410,240])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[775,240;815,240])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[380,110;380,60;515,60])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[585,70;690,70;690,350;750,350])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[585,60;705,60;705,230;750,230])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[585,50;720,50;720,105;750,105])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[780,115;795,115;795,225;815,225])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[795,360;795,255;815,255])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],[75,110;75,415;955,415])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],...
		'BackGround',7,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Calcul champ magntique',13,'terrestre1']],...
		'position',[160,86,285,164])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Drive non',13,'utilise']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Drive non',13,'utilise']],...
		'position',[510,140,515,145])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Sortie champ magntique rel',13,'utilis pour le calcul des moments',13,'magntiques']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Sortie champ magntique rel',13,'utilis pour le calcul des moments',13,'magntiques']],...
		'position',[675,260,680,265])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],'Location',[-32000,-32000,-31840,-31969])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ rel',13,'axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ rel',13,'axes satellite']],...
		'position',[1010,110,1015,115])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ rel satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ rel satellite']],...
		'position',[550,195,555,200])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ rel',13,'  ou',13,'puls']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ rel',13,'  ou',13,'puls']],...
		'position',[945,190,950,195])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive relle ou mesure',13,'non lisse']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive relle ou mesure',13,'non lisse']],...
		'position',[990,490,995,495])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/out_3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/out_3']],...
		'Port','3',...
		'position',[930,535,950,555])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive pulse non lisse']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive pulse non lisse']],...
		'position',[605,585,610,590])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive relle']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive relle']],...
		'position',[655,505,660,510])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Gain6']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Gain6']],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[715,485,850,525])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive B']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive B']],...
		'position',[485,420,490,425])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Sum3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Sum3']],...
		'hide name',0,...
		'position',[875,464,895,626])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/in_2']],...
		'Port','2',...
		'position',[120,470,140,490])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/out_1']],...
		'position',[925,120,945,140])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/in_1']],...
		'position',[125,350,145,370])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Sum']],...
		'hide name',0,...
		'position',[625,294,650,481])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Calcul t-nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Calcul t-nT']],...
		'hide name',0,...
		'position',[395,545,400,550])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Product']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Product']],...
		'position',[520,387,545,483])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],'Location',[115,469,1014,1003])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'position',[360,5,365,10])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/t-nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/t-nT']],...
		'position',[930,355,935,360])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/To Workspace4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/To Workspace4']],...
		'mat-name','temps',...
		'buffer','20000')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/To Workspace4']],...
		'position',[140,412,190,428])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Clock2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Clock2']],...
		'hide name',0,...
		'position',[45,330,85,370])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']],'Location',[125,659,765,904])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/in_1']],...
		'position',[245,115,265,135])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/out_1']],...
		'position',[525,105,545,125])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Calcul t-nT1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Calcul t-nT1']],...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Constant4']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Constant4']],...
		'Value','instant_injection')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Constant4']],...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Sum4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Sum4']],...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'Output Width','1')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Sum1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Sum1']],...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[175,70,180,75])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']],[270,125;290,125])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']],[500,115;520,115])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']],[345,145;345,85;470,85])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Subsystem']],...
		'hide name',0,...
		'position',[115,326,255,374])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Sortie de to = t -tinj - nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Sortie de to = t -tinj - nT']],...
		'position',[585,385,590,390])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Constant1']],...
		'position',[305,279,340,301])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Relational',13,'Operator']],...
		'position',[375,258,400,382])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/To Workspace3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/To Workspace3']],...
		'mat-name','champ1',...
		'buffer','20000')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/To Workspace3']],...
		'position',[610,272,660,288])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/out_2']],...
		'Port','3',...
		'position',[615,420,635,440])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Partie',13,'entire n1']],...
		'MATLAB Fcn','storcham(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Partie',13,'entire n1']],...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Partie',13,'entire n1']],...
		'position',[505,213,565,247])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Mux1']],...
		'inputs','[3 1]',...
		'position',[445,211,475,244])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/t - tinj- nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/t - tinj- nT']],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Sortie champ B chapeau']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Sortie champ B chapeau']],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Calcul t-nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Calcul t-nT']],...
		'hide name',0,...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Entre de B(t) //xyz ']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/Entre de B(t) //xyz ']],...
		'position',[115,180,120,185])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/in_1']],...
		'position',[65,210,85,230])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/out_3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/out_3']],...
		'position',[615,100,635,120])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE/out_1']],...
		'Port','2',...
		'position',[615,220,635,240])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[260,350;285,350;285,430;610,430])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[285,350;370,350])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[90,220;440,220])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[480,230;500,230])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[570,230;610,230])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[405,320;430,320;440,235])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[590,230;590,280;605,280])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[345,290;370,290])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[90,350;110,350])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[90,350;90,420;135,420])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],[390,220;390,110;610,110])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MESURE']],...
		'position',[285,325,420,395])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/derb_chapeau']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/derb_chapeau']],...
		'position',[520,495,525,500])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/t -tinj - nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/t -tinj - nT']],...
		'position',[485,385,490,390])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/B(n)']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/B(n)']],...
		'position',[520,335,525,340])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[115,280,120,285])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Temps']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Temps']],...
		'position',[115,445,120,450])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ  liss']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Champ  liss']],...
		'position',[765,335,770,340])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Gain3']],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[690,200,825,240])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Gain4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Gain4']],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[705,285,840,325])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Sum2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Sum2']],...
		'hide name',0,...
		'position',[870,179,890,341])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/out_2']],...
		'Port','2',...
		'position',[940,250,960,270])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Gain5']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Gain5']],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[710,565,845,605])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse=0 ce sont les conditions relles qui sont utilises']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse=0 ce sont les conditions relles qui sont utilises']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse=0 ce sont les conditions relles qui sont utilises']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse=0 ce sont les conditions relles qui sont utilises']],...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse=0 ce sont les conditions relles qui sont utilises']],...
		'position',[415,665,420,670])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse =1, ce sont les valeurs mesures qui sont utilises']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse =1, ce sont les valeurs mesures qui sont utilises']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse =1, ce sont les valeurs mesures qui sont utilises']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse =1, ce sont les valeurs mesures qui sont utilises']],...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Quand pulse =1, ce sont les valeurs mesures qui sont utilises']],...
		'position',[415,640,420,645])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MAGNETIQUE REEL OU PULSE ',13,'( AU CHOIX SUIVANT pul_datP ou pul_datNP )']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MAGNETIQUE REEL OU PULSE ',13,'( AU CHOIX SUIVANT pul_datP ou pul_datNP )']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MAGNETIQUE REEL OU PULSE ',13,'( AU CHOIX SUIVANT pul_datP ou pul_datNP )']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MAGNETIQUE REEL OU PULSE ',13,'( AU CHOIX SUIVANT pul_datP ou pul_datNP )']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MAGNETIQUE REEL OU PULSE ',13,'( AU CHOIX SUIVANT pul_datP ou pul_datNP )']],...
		'Font Size',20)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/CHAMP MAGNETIQUE REEL OU PULSE ',13,'( AU CHOIX SUIVANT pul_datP ou pul_datNP )']],...
		'position',[590,5,595,10])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/To Workspace5']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/To Workspace5']],...
		'hide name',0,...
		'mat-name','champ_pulse')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/To Workspace5']],...
		'buffer','20000',...
		'position',[800,373,920,407])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],'Location',[4,50,853,441])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Size',12)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'position',[420,45,425,50])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Size',12)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Entre de dB//dt //xyz ']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Entre de dB//dt //xyz ']],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Sortie B_prime']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Sortie B_prime']],...
		'position',[550,175,555,180])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Mux1']],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/t--tinj -nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/t--tinj -nT']],...
		'position',[335,235,340,240])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Relational',13,'Operator']],...
		'position',[375,168,400,292])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Constant1']],...
		'position',[325,189,360,211])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To Workspace5']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To Workspace5']],...
		'hide name',0,...
		'mat-name','derb_chapeau')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To Workspace5']],...
		'buffer','20000')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To Workspace5']],...
		'position',[630,268,750,302])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/t-tinj -nT<=Ta']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/t-tinj -nT<=Ta']],...
		'position',[390,290,395,295])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/in_1']],...
		'position',[105,135,125,155])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'MATLAB Fcn','storderB(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'position',[515,208,575,242])

add_block('built-in/To File',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To File']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To File']],...
		'File name','derbchap.mat')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To File']],...
		'Matrix name','derb_chapeau')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To File']],...
		'position',[635,134,730,166])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/out_1']],...
		'position',[715,215,735,235])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Sortie de t-tinj-nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Sortie de t-tinj-nT']],...
		'position',[395,310,400,315])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/B(n)']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/B(n)']],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_chapeau']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/derb_chapeau']],...
		'position',[785,211,790,216])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To Workspace7']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To Workspace7']],...
		'hide name',0,...
		'mat-name','der_seconde')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To Workspace7']],...
		'buffer','20000')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/To Workspace7']],...
		'position',[705,568,825,602])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']],'Location',[125,1114771,765,1115016])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/in_1']],...
		'position',[245,115,265,135])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/out_1']],...
		'position',[525,105,545,125])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Calcul t-nT1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Calcul t-nT1']],...
		'position',[460,206,465,211])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Constant4']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Constant4']],...
		'Value','instant_injection')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Constant4']],...
		'position',[165,154,270,176])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Sum4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Sum4']],...
		'position',[295,107,320,183])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'Output Width','1')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Sum1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Sum1']],...
		'position',[475,54,495,176])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[175,70,180,75])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']],[270,125;290,125])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']],[500,115;520,115])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']],[345,145;345,85;470,85])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Subsystem']],...
		'hide name',0,...
		'position',[155,236,295,284])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE/in_2']],...
		'Port','2',...
		'position',[95,250,115,270])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],[300,260;370,260])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],[130,145;430,145;430,215;450,215])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],[365,200;370,200])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],[405,230;450,230])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],[490,225;510,225])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],[580,225;710,225])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],[595,225;595,285;625,285])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],[595,225;595,150;630,150])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],[120,260;150,260])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/DERIVEE MESUREE']],...
		'position',[290,415,425,495])

add_block('built-in/Derivative',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive de',13,'B relle']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1/Drive de',13,'B relle']],...
		'position',[195,417,250,453])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[150,360;280,360])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[260,360;175,360;175,435;190,435])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[425,360;565,360;565,340;620,340])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[425,385;440,385;440,410;515,410])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[430,455;515,460])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[655,390;795,390])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[550,435;620,435])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[255,435;285,435])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[460,457;460,585;705,585])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[425,335;450,335;450,220;685,220])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[670,390;670,305;700,305])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[830,220;865,220])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[845,305;865,300])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[895,260;935,260])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[640,220;640,130;920,130])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[855,505;870,505])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[850,585;870,585])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[900,545;925,545])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[145,480;165,480;165,475;285,475])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],[255,435;255,505;710,505])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],...
		'Mask Display','Champ rel\n&\nchamp mesur')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Subsystem1']],...
		'hide name',0,...
		'position',[330,86,455,164])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/out_1']],...
		'position',[680,110,715,140])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Champ mesur liss']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Champ mesur liss']],...
		'position',[610,95,615,100])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/ou rel']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/ou rel']],...
		'position',[615,125,620,130])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/Sortie Bx By Bz']],...
		'position',[690,155,695,160])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1/out_2']],...
		'Port','2',...
		'position',[685,210,720,240])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1']],[70,125;155,125])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1']],[290,105;325,105])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1']],[290,145;325,145])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1']],[460,125;675,125])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1']],[460,100;555,100;555,225;680,225])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique',13,'en axes satellite1']],...
		'position',[365,460,565,535])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique rel']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ magntique rel']],...
		'position',[815,650,820,655])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Sortie des angles',13,'pour la suite']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Sortie des angles',13,'pour la suite']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Sortie des angles',13,'pour la suite']],...
		'position',[800,545,805,550])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ B puls axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ B puls axes satellite']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Champ B puls axes satellite']],...
		'position',[825,480,830,485])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/out_2']],...
		'Port','2',...
		'position',[1005,580,1025,600])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/out_4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/out_4']],...
		'Port','4',...
		'position',[1005,640,1025,660])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],'Location',[4,50,856,463])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Gain2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Gain2']],...
		'Gain','gain_roulis',...
		'position',[595,233,640,257])

add_block('built-in/Transfer Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Filtre passe bas',13,'roulis']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Filtre passe bas',13,'roulis']],...
		'Denominator','[1 1/0.8]',...
		'position',[680,220,740,270])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/out_1']],...
		'position',[775,235,795,255])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Gain1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Gain1']],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_ROULIS',...
		'position',[445,224,500,266])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/ROUE']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/ROUE']],...
		'hide name',0,...
		'position',[449,170,454,175])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Sum']],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[535,137,565,353])

add_block('built-in/Derivative',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Derivative']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Derivative']],...
		'position',[365,225,410,265])

add_block('built-in/Transfer Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Intgrateur']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Intgrateur']],...
		'BackGround',7,...
		'Numerator','[I_PID_ROULIS]',...
		'Denominator','[1 0]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Intgrateur']],...
		'position',[350,294,435,336])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Gain']],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_ROULIS',...
		'position',[370,156,445,194])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/gain 0 ou 1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/gain 0 ou 1']],...
		'Gain','0.5*0',...
		'position',[465,302,495,328])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Rappel proportionnel']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Rappel proportionnel']],...
		'position',[400,190,405,195])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/roulisref - roulis ']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/roulisref - roulis ']],...
		'position',[280,135,285,140])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Rappel',13,'proportionnel']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/Rappel',13,'proportionnel']],...
		'ForeGround',1,...
		'position',[465,140,470,145])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/in_1']],...
		'position',[265,165,285,185])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/PID ROULIS']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/PID ROULIS']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis/PID ROULIS']],...
		'position',[510,70,515,75])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[745,245;770,245])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[500,315;530,315])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[440,315;460,315])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[505,245;530,245])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[415,245;440,245])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[450,175;530,175])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[290,175;365,175])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[345,175;320,175;320,315;345,315])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[320,245;360,245])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[645,245;675,245])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],[570,245;590,245])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],...
		'Mask Display','PID ROULIS SEUL')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID roulis']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[560,223,710,277])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Vitesses',13,'inutiles']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Vitesses',13,'inutiles']],...
		'position',[180,190,185,195])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Entre des angles',13,'roulis et lacet']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Entre des angles',13,'roulis et lacet']],...
		'Font Name','@Arial Unicode MS',...
		'Font Weight','bold',...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Entre des angles',13,'roulis et lacet']],...
		'position',[390,150,395,155])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Sum1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[410,240,440,315])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4']],'Location',[31,157,323,338])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4/Mux']],...
		'inputs','2',...
		'position',[175,57,205,133])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4/out_1']],...
		'position',[240,85,260,105])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4/Constant3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4/Constant3']],...
		'hide name',0,...
		'Value','consigne_lacet',...
		'position',[25,104,130,126])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4/Constant1']],...
		'hide name',0,...
		'Value','consigne_roulis',...
		'position',[25,62,135,88])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4']],[140,75;170,75])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4']],[135,115;170,115])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4']],[210,95;235,95])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4']],...
		'Mask Display','Consigne\nroulis(1) lacet(2)')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/UnNamed4']],...
		'hide name',0,...
		'position',[290,242,385,278])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Demux']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Demux']],...
		'hide name',0,...
		'outputs','2',...
		'position',[465,223,500,332])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Sortie roulis(1)',13,'lacet(2)']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Sortie roulis(1)',13,'lacet(2)']],...
		'position',[345,295,350,300])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Consigne-Angles']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Consigne-Angles']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Consigne-Angles']],...
		'position',[365,325,370,330])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Constant']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Constant']],...
		'hide name',0,...
		'Value','consigne_tangage',...
		'position',[290,360,400,380])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Sum2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Sum2']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[415,345,445,420])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],'Location',[68,593,677,948])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Ecart teta_ref - teta']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Ecart teta_ref - teta']],...
		'position',[70,40,75,45])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Rappel proportionnel']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Rappel proportionnel']],...
		'position',[190,95,195,100])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/gain 0 ou 1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/gain 0 ou 1']],...
		'Gain','0',...
		'position',[255,207,285,233])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Gain']],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_TANGAGE',...
		'position',[160,61,235,99])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/in_1']],...
		'position',[55,70,75,90])

add_block('built-in/Transfer Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Intgrateur']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Intgrateur']],...
		'BackGround',7,...
		'Numerator','[I_PID_TANGAGE]',...
		'Denominator','[1 0]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Intgrateur']],...
		'position',[155,199,225,241])

add_block('built-in/Derivative',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Derivative']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Derivative']],...
		'position',[155,130,200,170])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Sum']],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[325,42,355,258])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/ROUE']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/ROUE']],...
		'hide name',0,...
		'position',[239,75,244,80])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Gain1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Gain1']],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_TANGAGE',...
		'position',[235,129,290,171])

add_block('built-in/Transfer Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Filtre passe bas']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Filtre passe bas']],...
		'Denominator','[1 1/0.8]',...
		'position',[455,125,515,175])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Gain2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/Gain2']],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','gain_tangage',...
		'position',[375,129,430,171])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/commande_pid']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage/commande_pid']],...
		'position',[555,140,575,160])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[290,220;320,220])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[230,220;250,220])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[295,150;320,150])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[205,150;230,150])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[240,80;320,80])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[80,80;155,80])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[520,150;550,150])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[110,80;110,220;150,220])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[110,150;150,150])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[360,150;370,150])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],[435,150;450,150])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],...
		'Mask Display','P.I.D TANGAGE')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID tangage']],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[565,352,710,418])


%     Subsystem  ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet'].

new_system([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],'Location',[80,578,770,943])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Rappel',13,'proportionnel1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Rappel',13,'proportionnel1']],...
		'ForeGround',1,...
		'position',[315,75,320,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/lacet_ref - lacet  ']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/lacet_ref - lacet  ']],...
		'position',[125,90,130,95])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Rappel proportionnel1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Rappel proportionnel1']],...
		'position',[245,145,250,150])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/gain 0 ou 2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/gain 0 ou 2']],...
		'Gain','0.5*0',...
		'position',[310,257,340,283])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Gain2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Gain2']],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','K_PID_LACET',...
		'position',[215,111,290,149])

add_block('built-in/Transfer Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Intgrateur1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Intgrateur1']],...
		'BackGround',7,...
		'Numerator','[I_PID_LACET]',...
		'Denominator','[1 0]')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Intgrateur1']],...
		'position',[210,249,280,291])

add_block('built-in/Derivative',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Derivative1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Derivative1']],...
		'position',[210,180,255,220])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Sum1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Sum1']],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','+++',...
		'position',[380,92,410,308])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/ROUE1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/ROUE1']],...
		'hide name',0,...
		'position',[294,125,299,130])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Gain3']],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','F_PID_LACET',...
		'position',[290,179,345,221])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/out_1']],...
		'position',[580,190,600,210])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/in_1']],...
		'position',[115,120,135,140])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Gain4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Gain4']],...
		'Gain','gain_lacet',...
		'position',[440,187,465,213])

add_block('built-in/Transfer Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Filtre passe bas',13,'lacet']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/Filtre passe bas',13,'lacet']],...
		'Denominator','[1 1/0.8]',...
		'position',[485,175,545,225])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/PID LACET']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/PID LACET']],...
		'ForeGround',1,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet/PID LACET']],...
		'position',[335,20,340,25])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[140,130;210,130])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[190,130;165,130;165,270;205,270])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[165,200;205,200])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[295,130;375,130])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[260,200;285,200])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[350,200;375,200])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[285,270;305,270])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[345,270;375,270])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[550,200;575,200])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[470,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],[415,200;435,200])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],...
		'Mask Display','PID LACET SEUL')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/PID lacet']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[560,278,710,332])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Calcul des couples ',13,'de commandes ',13,'Cphi Cteta Cpsi']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Calcul des couples ',13,'de commandes ',13,'Cphi Cteta Cpsi']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Calcul des couples ',13,'de commandes ',13,'Cphi Cteta Cpsi']],...
		'position',[1160,255,1165,260])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/To Workspace1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/To Workspace1']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','cpl_phi',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/To Workspace1']],...
		'position',[995,242,1045,258])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Gain4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Gain4']],...
		'hide name',0,...
		'position',[910,373,935,397])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Gain']],...
		'hide name',0,...
		'position',[915,238,940,262])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/out_1']],...
		'position',[1050,470,1070,490])

add_block('built-in/Fcn',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Fcn']],...
		'Expr','cos(u)',...
		'position',[685,435,725,455])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Angle de tangage']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Angle de tangage']],...
		'position',[500,420,505,425])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Product']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Product']],...
		'position',[795,291,825,344])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Product1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Product1']],...
		'position',[805,414,835,456])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/To Workspace2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/To Workspace2']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','cpl_teta',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/To Workspace2']],...
		'position',[1015,447,1065,463])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/To Workspace3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/To Workspace3']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','cpl_psi',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/To Workspace3']],...
		'position',[1020,427,1070,443])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/Mux3']],...
		'hide name',0,...
		'inputs','3',...
		'position',[1030,323,1060,427])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/out_3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem/out_3']],...
		'Port','3',...
		'position',[1165,365,1185,385])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[940,385;955,385;955,375;1025,375])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[945,250;965,250;965,340;1025,340])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[715,250;910,250])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[505,250;555,250])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[505,305;555,305])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[140,295;180,295;180,500;220,500])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[165,295;165,400;410,400])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[140,335;230,335])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[150,335;150,525;220,525])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[405,370;410,365])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[450,385;560,385])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[140,255;230,255])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[210,255;220,475])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[270,500;360,500])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[285,295;405,295])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[390,260;405,260])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[445,280;460,280])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[65,275;85,275])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[1065,375;1160,375])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[307,500;305,590;1000,590])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[945,250;990,250])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[955,385;955,455;1010,455])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[570,480;1045,480])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[570,515;615,515;615,650;1000,650])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[360,400;360,445;680,445])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[730,445;800,445])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[715,385;740,385;740,425;800,425])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[840,435;855,435;855,385;905,385])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[830,320;875,320;875,410;1025,410])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[985,410;985,435;1015,435])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[715,305;790,305])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],[760,445;760,330;790,330])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],...
		'Mask Display','CALCUL DES COUPLES PID\nSUR AXES DE MESURE\nDES ANGLES DE CARDAN\n\n1 champ puls\n2 Angles de Cardan\n3 Les 3 PID\n4 Le champ rel')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Subsystem']],...
		'position',[50,268,225,407])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/in_1']],...
		'position',[10,330,30,350])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Champ magntique rel ']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Champ magntique rel ']],...
		'position',[820,460,825,465])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Champ magntique puls']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Champ magntique puls']],...
		'position',[305,255,310,260])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Champ rel']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/Champ rel']],...
		'position',[330,560,335,565])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/To Workspace2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3/To Workspace2']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','By',...
		'buffer','points_trace',...
		'position',[545,233,590,247])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[35,340;45,340])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[230,320;255,320])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[230,355;255,355])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[230,285;435,285])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[485,285;505,285])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[485,440;585,440;585,305;605,305])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[555,285;605,285])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[485,370;510,370])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[545,370;605,370])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[555,285;555,390;605,390])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[390,340;425,340;435,405])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[405,340;405,515;445,515])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[420,285;420,490;445,490])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[480,505;610,505])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[555,390;555,485;610,485])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[710,340;720,340])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[790,340;800,340])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[645,380;655,380;655,340;670,340])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[650,495;655,495;655,385;670,385])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[850,340;900,340])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[850,315;880,315;880,250;900,250])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[870,295;900,295])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[865,315;865,205;880,205])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[885,340;885,390;900,390])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[1005,435;1015,435])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[940,295;955,295;965,400])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[970,530;1010,530])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[990,620;1010,620])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[850,365;860,365;860,575;1010,575])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[860,575;830,575])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[1085,435;1100,435])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[1050,575;1075,575;1075,520;1100,520])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[1135,480;1160,480])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[865,575;865,670;1175,670])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[305,340;320,340])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[645,295;670,295])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[230,390;270,390;270,585;695,585;695,465;965,465])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],[495,285;495,240;540,240])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],...
		'Mask Display','COMMANDE 2 AXES ROULIS-LACET\n\nAVEC 2 BOBINES ROULIS-LACET\n\nCOMMANDE TANGAGE SEUL PAR ROUE')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12)
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Subsystem3']],...
		'position',[385,95,730,195])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/out_1']],...
		'position',[815,110,835,130])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Couple total']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Couple total']],...
		'position',[885,105,890,110])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Couple roue',13,'unidimensionnel']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Couple roue',13,'unidimensionnel']],...
		'position',[900,150,905,155])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/out_2']],...
		'Port','2',...
		'position',[815,160,835,180])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace1']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[430,240,490,260])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace2']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[430,275,490,295])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace3']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace3']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[425,310,490,330])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Demux2']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/Demux2']],...
		'outputs','3',...
		'position',[330,230,375,340])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/in_1']],...
		'position',[10,135,30,155])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace4']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace4']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','pqr',...
		'buffer','points_trace',...
		'position',[170,35,235,55])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace5']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/To Workspace5']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','ptf',...
		'buffer','points_trace',...
		'position',[220,355,285,375])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/vitesses']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/vitesses']],...
		'position',[200,55,205,60])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/angles']])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling/angles']],...
		'position',[255,375,260,380])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[365,145;380,145])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[190,170;320,170])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[105,170;120,170])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[35,145;50,145])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[220,170;230,115])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[300,115;320,115])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[735,120;810,120])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[735,170;810,170])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[380,250;425,250])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[380,285;425,285])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[380,320;420,320])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[300,115;300,285;325,285])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[105,115;140,115;140,45;165,45])
add_line([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],[200,170;200,365;215,365])
set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],...
		'Mask Display','ACQUISITION FINALE\nAPRES DETUMBLING')


%     Finished composite block ['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling'].

set_param([sys,'/',['F(X,t) pour la rotation/Acquisition finale aprs',13,'dtumbling']],...
		'hide name',0,...
		'position',[125,447,355,538])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Cz',...
		'buffer','points_trace',...
		'position',[890,577,940,593])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace2'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Cy',...
		'buffer','points_trace',...
		'position',[890,542,940,558])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace1'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Cx',...
		'buffer','points_trace',...
		'position',[890,507,940,523])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain4'])
set_param([sys,'/','F(X,t) pour la rotation/Gain4'],...
		'hide name',0,...
		'position',[945,412,970,438])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Matrix Gain applique',13,'aux couples externes']])
set_param([sys,'/',['F(X,t) pour la rotation/Matrix Gain applique',13,'aux couples externes']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['F(X,t) pour la rotation/Matrix Gain applique',13,'aux couples externes']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[820,402,920,448])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum'])
set_param([sys,'/','F(X,t) pour la rotation/Sum'],...
		'position',[750,335,775,515])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],'Location',[4,50,1267,947])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[211,287,1057,756])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/To Workspace']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/To Workspace']],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','BY',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/To Workspace']],...
		'position',[585,38,630,52])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Demux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Demux1']],...
		'outputs','3',...
		'position',[495,29,535,61])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[540,45;580,45])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[445,120;445,45;490,45])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'ForeGround',7,...
		'BackGround',3,...
		'hide name',0,...
		'position',[245,355,470,405])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Gain'],...
		'hide name',0,...
		'position',[555,367,580,393])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Sum1'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[1025,227,1050,683])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Q'])
set_param([sys,'/','F(X,t) pour la rotation/Q'],...
		'position',[215,310,220,315])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Inport'])
set_param([sys,'/','F(X,t) pour la rotation/Inport'],...
		'position',[50,285,70,305])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Demux'],...
		'outputs','[3 4]',...
		'position',[155,238,200,347])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[75,210,80,215])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/pqr'])
set_param([sys,'/','F(X,t) pour la rotation/pqr'],...
		'position',[240,235,245,240])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Derivrot'])
set_param([sys,'/','F(X,t) pour la rotation/Derivrot'],...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[300,236,435,294])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Gain1'],...
		'position',[1090,442,1115,468])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/out_1'],...
		'position',[1155,445,1175,465])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Second membre',13,'des quations du TMC',13,'concernant le vecteur rotation',13,'seul (p q r )']])
set_param([sys,'/',['F(X,t) pour la rotation/Second membre',13,'des quations du TMC',13,'concernant le vecteur rotation',13,'seul (p q r )']],...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[1155,350,1160,355])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux1'])
set_param([sys,'/','F(X,t) pour la rotation/Demux1'],...
		'outputs','3',...
		'position',[785,495,830,605])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Suppression possible',13,'de tous les couples']])
set_param([sys,'/',['F(X,t) pour la rotation/Suppression possible',13,'de tous les couples']],...
		'position',[955,355,960,360])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Sorties des commande en',13,'axes satellite x y z']])
set_param([sys,'/',['F(X,t) pour la rotation/Sorties des commande en',13,'axes satellite x y z']],...
		'position',[915,470,920,475])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Gain2'],...
		'hide name',0,...
		'position',[635,457,660,483])


%     Subsystem  'F(X,t) pour la rotation/Hachoir pulse'.

new_system([sys,'/','F(X,t) pour la rotation/Hachoir pulse'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse'],'Location',[307,509,1144,814])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/out_1'],...
		'position',[635,140,655,160])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/in_1'],...
		'position',[65,100,85,120])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[230,170,365,210])


%     Subsystem  'F(X,t) pour la rotation/Hachoir pulse/Subsystem5'.

new_system([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'],'Location',[307,509,1144,814])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/out_1'],...
		'position',[635,140,655,160])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/in_1'],...
		'position',[65,100,85,120])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[230,170,365,210])


%     Subsystem  'F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'.

new_system([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'],'Location',[580,281,938,501])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','valeur_creneau',...
		'buffer','points_trace')
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/To Workspace3'],...
		'position',[245,178,340,192])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/MATLAB Fcn'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/Product'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/CRENEAU'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/To Workspace4'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_creneau',...
		'buffer','points_trace')
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5/To Workspace4'],...
		'position',[125,193,220,207])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'],[185,130;225,130])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'],[205,130;205,185;240,185])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'],[85,130;115,130])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'],[255,110;290,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'],[140,85;225,85])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'],[85,130;85,195;120,200])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'.

set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5/Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[175,84,300,136])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'],[90,110;125,110;125,190;225,190])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'],[550,150;630,150])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'],[305,110;335,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'],[370,190;520,190])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'],[480,110;520,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'],[90,110;170,110])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'F(X,t) pour la rotation/Hachoir pulse/Subsystem5'.

set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse/Subsystem5'],...
		'hide name',0,...
		'position',[195,86,280,134])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse'],[90,110;125,110;125,190;225,190])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse'],[550,150;630,150])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse'],[370,190;520,190])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse'],[480,110;520,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse'],[90,110;190,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse'],[285,110;335,110])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'F(X,t) pour la rotation/Hachoir pulse'.

set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse'],...
		'hide name',0,...
		'position',[465,446,550,494])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Couple roue'])
set_param([sys,'/','F(X,t) pour la rotation/Couple roue'],...
		'position',[960,600,965,605])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/magneto.m2'])
set_param([sys,'/','F(X,t) pour la rotation/magneto.m2'],...
		'hide name',0,...
		'MATLAB Fcn','jw_rotot(u)',...
		'Output Width','3',...
		'Mask Display','Participation\nde la roue',...
		'position',[820,631,955,689])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain5'])
set_param([sys,'/','F(X,t) pour la rotation/Gain5'],...
		'hide name',0,...
		'position',[970,647,995,673])


%     Subsystem  'F(X,t) pour la rotation/Hachoir pulse1'.

new_system([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'],'Location',[307,509,1144,814])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/out_1'],...
		'position',[635,140,655,160])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/in_1'],...
		'position',[65,100,85,120])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[230,170,365,210])


%     Subsystem  'F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'.

new_system([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'],'Location',[307,509,1144,814])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/out_1'],...
		'position',[635,140,655,160])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/in_1'],...
		'position',[65,100,85,120])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[230,170,365,210])


%     Subsystem  'F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'.

new_system([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'],'Location',[580,281,938,501])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','valeur_creneau',...
		'buffer','points_trace')
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/To Workspace3'],...
		'position',[245,178,340,192])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/MATLAB Fcn'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/Product'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/CRENEAU'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/To Workspace4'])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_creneau',...
		'buffer','points_trace')
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5/To Workspace4'],...
		'position',[125,193,220,207])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'],[185,130;225,130])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'],[205,130;205,185;240,185])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'],[85,130;115,130])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'],[255,110;290,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'],[140,85;225,85])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'],[85,130;85,195;120,200])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'.

set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5/Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[175,84,300,136])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'],[90,110;125,110;125,190;225,190])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'],[550,150;630,150])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'],[305,110;335,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'],[370,190;520,190])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'],[480,110;520,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'],[90,110;170,110])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'.

set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1/Subsystem5'],...
		'hide name',0,...
		'position',[195,86,280,134])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'],[90,110;125,110;125,190;225,190])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'],[550,150;630,150])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'],[370,190;520,190])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'],[480,110;520,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'],[90,110;190,110])
add_line([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'],[285,110;335,110])
set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'F(X,t) pour la rotation/Hachoir pulse1'.

set_param([sys,'/','F(X,t) pour la rotation/Hachoir pulse1'],...
		'hide name',0,...
		'position',[700,636,785,684])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Hachoir de la',13,'roue qui coupe',13,'la roue pendant',13,'les mesures']])
set_param([sys,'/',['F(X,t) pour la rotation/Hachoir de la',13,'roue qui coupe',13,'la roue pendant',13,'les mesures']],...
		'position',[745,685,750,690])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Suppression ',13,'possible de la roue']])
set_param([sys,'/',['F(X,t) pour la rotation/Suppression ',13,'possible de la roue']],...
		'position',[1000,685,1005,690])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Somme des couples',13,'externes']])
set_param([sys,'/',['F(X,t) pour la rotation/Somme des couples',13,'externes']],...
		'position',[745,290,750,295])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux2'])
set_param([sys,'/','F(X,t) pour la rotation/Demux2'],...
		'outputs','3',...
		'position',[410,409,450,441])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux3'])
set_param([sys,'/','F(X,t) pour la rotation/Demux3'],...
		'outputs','3',...
		'position',[610,404,650,436])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace5'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','com_apres',...
		'buffer','points_trace',...
		'position',[670,403,740,417])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace4'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace4'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','com_avant',...
		'buffer','points_trace',...
		'position',[470,405,545,425])
add_line([sys,'/','F(X,t) pour la rotation'],[205,265;295,265])
add_line([sys,'/','F(X,t) pour la rotation'],[1055,455;1085,455])
add_line([sys,'/','F(X,t) pour la rotation'],[1120,455;1150,455])
add_line([sys,'/','F(X,t) pour la rotation'],[75,295;150,295])
add_line([sys,'/','F(X,t) pour la rotation'],[475,380;550,380])
add_line([sys,'/','F(X,t) pour la rotation'],[115,295;115,380;240,380])
add_line([sys,'/','F(X,t) pour la rotation'],[780,425;815,425])
add_line([sys,'/','F(X,t) pour la rotation'],[925,425;940,425])
add_line([sys,'/','F(X,t) pour la rotation'],[115,350;90,350;90,495;120,495])
add_line([sys,'/','F(X,t) pour la rotation'],[415,560;425,560])
add_line([sys,'/','F(X,t) pour la rotation'],[665,470;745,470])
add_line([sys,'/','F(X,t) pour la rotation'],[585,380;745,380])
add_line([sys,'/','F(X,t) pour la rotation'],[707,470;705,550;780,550])
add_line([sys,'/','F(X,t) pour la rotation'],[835,515;885,515])
add_line([sys,'/','F(X,t) pour la rotation'],[835,550;885,550])
add_line([sys,'/','F(X,t) pour la rotation'],[835,585;885,585])
add_line([sys,'/','F(X,t) pour la rotation'],[960,660;965,660])
add_line([sys,'/','F(X,t) pour la rotation'],[975,425;995,425;995,455;1020,455])
add_line([sys,'/','F(X,t) pour la rotation'],[360,515;365,515;365,560;380,560])
add_line([sys,'/','F(X,t) pour la rotation'],[580,560;610,560])
add_line([sys,'/','F(X,t) pour la rotation'],[90,495;90,620;610,620])
add_line([sys,'/','F(X,t) pour la rotation'],[1000,660;1000,605;1020,605])
add_line([sys,'/','F(X,t) pour la rotation'],[440,265;915,265;915,305;1020,305])
add_line([sys,'/','F(X,t) pour la rotation'],[555,470;630,470])
add_line([sys,'/','F(X,t) pour la rotation'],[360,470;460,470])
add_line([sys,'/','F(X,t) pour la rotation'],[790,660;815,660])
add_line([sys,'/','F(X,t) pour la rotation'],[655,590;675,590;675,660;695,660])
add_line([sys,'/','F(X,t) pour la rotation'],[380,470;380,425;405,425])
add_line([sys,'/','F(X,t) pour la rotation'],[455,415;465,415])
add_line([sys,'/','F(X,t) pour la rotation'],[655,410;665,410])
add_line([sys,'/','F(X,t) pour la rotation'],[580,470;580,420;605,420])
set_param([sys,'/','F(X,t) pour la rotation'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'F(X,t) pour la rotation'.

set_param([sys,'/','F(X,t) pour la rotation'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[130,248,355,332])


%     Subsystem  'F(X,t) pour le quuaternion'.

new_system([sys,'/','F(X,t) pour le quuaternion'])
set_param([sys,'/','F(X,t) pour le quuaternion'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['F(X,t) pour le quuaternion/Drive du quaternion d''attitude']])
set_param([sys,'/',['F(X,t) pour le quuaternion/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','F(X,t) pour le quuaternion/Outport'])
set_param([sys,'/','F(X,t) pour le quuaternion/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','F(X,t) pour le quuaternion/Inport'])
set_param([sys,'/','F(X,t) pour le quuaternion/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour le quuaternion/deriv_qt.m'])
set_param([sys,'/','F(X,t) pour le quuaternion/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','F(X,t) pour le quuaternion'],[225,55;255,55])
add_line([sys,'/','F(X,t) pour le quuaternion'],[105,55;145,55])
set_param([sys,'/','F(X,t) pour le quuaternion'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'F(X,t) pour le quuaternion'.

set_param([sys,'/','F(X,t) pour le quuaternion'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[130,383,345,487])
add_line(sys,[745,365;765,365;765,520;55,520;55,435;125,435])
add_line(sys,[580,365;635,365])
add_line(sys,[360,290;510,290])
add_line(sys,[350,435;510,435])
add_line(sys,[765,365;765,295;825,295])
add_line(sys,[615,365;615,330;825,330])
add_line(sys,[55,435;55,290;125,290])
add_line(sys,[765,355;765,295;725,295])
add_line(sys,[765,415;840,415])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
